@@ -61,7 +61,7 @@ extern int compute_size_params(SEA_VIEW *view, int force_recompute);
 extern char **prepcolranks_by_codon(char **seq, int totseqs, int maxlen, int *eachlength, char **comments);
 extern int is_view_valid(SEA_VIEW *view);
 #ifdef WIN32
-extern "C" { int mysystem(const char *command); }
+extern int mysystem(const char *command);
 #endif
 
 
@@ -322,7 +322,7 @@ if(withU) {
 	}	
 lfrag = strlen(seq[0]); /* long alignement de clustalw */
 lpart = fin - debut + 1; /*long region traitee de l'ancien alignement multiple*/
-if( num = reset_stars(view, debut, lpart, seq, lfrag, tmpselseqs) ) {
+if( (num = reset_stars(view, debut, lpart, seq, lfrag, tmpselseqs)) ) {
   *err_message = "Error: mismatch between alignment input and output.";
   return TRUE;
   }
@@ -1014,7 +1014,7 @@ int profile_dialog(SEA_VIEW *view)
   else propagate->value(1);
 	y += 25;
 	Fl_Button *cancel_button = new Fl_Button(5, y, 60, 20, "Cancel");
-	cancel_button->shortcut(myFL_CTRL | 'w');
+	cancel_button->shortcut(FL_COMMAND | 'w');
 	Fl_Button *help_button = new Fl_Button(97, y, 60, 20, "Help");
 	Fl_Button *ok_button = new Fl_Return_Button(190, y, 60, 20, "OK");
 	w->end();
