@@ -233,7 +233,7 @@ if(win == NULL) {
 	w = 45;
 	y += 10;
 	Fl_Button *ignore = new Fl_Button(win->w() - w - 5,y,w,20, "Close");
-	ignore->shortcut(myFL_CTRL | 'w');
+	ignore->shortcut(FL_COMMAND | 'w');
 	ignore->color(FL_LIGHT2);
 	ignore->callback(ignore_cb);
 	win->end();
@@ -628,7 +628,7 @@ int colorcell::handle(int event)
 			this->take_focus();
 			break;
 		case FL_KEYBOARD:
-			if( Fl::event_state(myFL_CTRL) ) return 0; // can be shortcut of other widgets
+			if( Fl::event_state(FL_COMMAND) ) return 0; // can be shortcut of other widgets
 			if(Fl::event_length() == 0) break;
 			key = Fl::event_text()[0];
 			key = toupper(key);
@@ -824,7 +824,7 @@ codon_color_chooser::codon_color_chooser(coloraas *in_coloraas) : Fl_Window(330,
 	Fl_Button *cancel = new Fl_Button(5, 390, 60, 20, "Cancel");
 	cancel->callback(cancel_cb, NULL);
 	cancel->tooltip("don't change anything");
-	cancel->shortcut(myFL_CTRL | 'w');
+	cancel->shortcut(FL_COMMAND | 'w');
 	Fl_Button *reset = new Fl_Button(100, 390, 60, 20, "Reset");
 	reset->callback(reset_cb, NULL);
 	reset->tooltip("back to previous color set");
