@@ -210,7 +210,7 @@ if(first) {
 	obj = cre_adjusted_button(fin,top->y(),&width,top->h(),
 		"Cancel");
 	obj->callback(hide_window_callback, NULL);
-	((Fl_Button *)obj)->shortcut(myFL_CTRL | 'w');
+	((Fl_Button *)obj)->shortcut(FL_COMMAND | 'w');
 	fin += width;
 	
 	top->resizable(NULL);
@@ -439,7 +439,7 @@ if(first) {
 	
 	obj = cre_adjusted_button(fin,5,&width,25,"Cancel");
 	obj->callback(hide_window_callback, NULL);
-	((Fl_Button *)obj)->shortcut(myFL_CTRL | 'w');
+	((Fl_Button *)obj)->shortcut(FL_COMMAND | 'w');
 	fin += width + 5;
 	
 	obj = cre_adjusted_button(fin,5,&width,25,"Refresh");
@@ -516,7 +516,7 @@ fin += width + 5;
 
 obj = cre_adjusted_button(fin,5,&width,25,"Cancel");
 obj->callback(close_editseqwin_callback, editdata);
-((Fl_Button *)obj)->shortcut(myFL_CTRL | 'w');
+((Fl_Button *)obj)->shortcut(FL_COMMAND | 'w');
 fin += width + 5;
 
 editdata->name = new Fl_Box(FL_DOWN_BOX, fin, 5, 
