@@ -12,7 +12,11 @@ typedef int NSInteger;
 typedef unsigned int NSUInteger;
 #endif
 #endif
+#ifndef kCGColorSpaceUserRGB // needed from 10.6
+#define kCGColorSpaceUserRGB  CFSTR("kCGColorSpaceUserRGB")
+#endif
 #include "seaview.h"
+#include "treedraw.h"
 #include <FL/x.H>
 #include <FL/Fl_Sys_Menu_Bar.H>
 #include <FL/Fl_Help_View.H>
@@ -24,13 +28,9 @@ typedef unsigned int NSUInteger;
 // included functions
 char *mac_fname_to_roman(const char *in);
 void fl_ringbell(int a);
-extern "C" {
-	const char *MG_GetBundleResourcesDir(void);
-	void PtoC(const void *in, void *out);
-	void CtoP(const void *in, void *out);
-	void show_apropos(Fl_Widget *, void *unused);
-	void MG_apple_inits(void);
-}
+const char *MG_GetBundleResourcesDir(void);
+void show_apropos(Fl_Widget *, void *unused);
+void MG_apple_inits(void);
 void set_seaview_modified(SEA_VIEW *view, int ismodified);
 void windowmenuitem_callback(Fl_Widget *o, void *data);
 int find_windowmenuitem(Fl_Window *w);
@@ -38,17 +38,8 @@ int add_windowmenuitem(const char *name, Fl_Window *w);
 void rename_windowmenuitem(const char *name, int rank);
 void delete_windowmenuitem(int rank);
 char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int, const char *directory);
-void MG_fl_draw(const char *txt, int x, int y);
-void MG_fl_line(int x, int y, int x1, int y1);
-void MG_fl_rect(int x, int y, int w, int h);
-void MG_fl_rectf(int x, int y, int w, int h);
-void MG_fl_font(int fontrank, int size);
-void MG_fl_color(Fl_Color color);
-float MG_fl_width(char *txt, int l);
-void *MG_PrepareCopy(int w, int h);
-void MG_CompleteCopy(void *mypicture);
 static size_t MyPutBytes (void* info, const void* buffer, size_t count);
-#if !__LP64__
+#ifdef USE_PICT
 QDPictRef MyPictToQDPict(PicHandle mypicture);
 void MyCopyPictToClipboard (PicHandle mypicture);
 #endif
@@ -64,9 +55,6 @@ extern int printout_vary, printout_black;
 extern paperformat printout_pageformat;
 
 /* globals */
-#if !__LP64__
-static int MG_doing_copy = 0;
-#endif
 
 void fl_ringbell(int a)
 {
@@ -238,7 +226,7 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
     printout_black = [pdfmatrix selectedRow];
     printout_pageformat = (paperformat)[papermatrix selectedRow];
     printout_vary = [variable intValue];
-    strcpy(pathname, [[_panel filename] fileSystemRepresentation]);
+    strcpy(pathname, [[[_panel URL] path] UTF8String]);
     }
   [localPool release];
   if ( retval == NSCancelButton ) return NULL;
@@ -302,7 +290,7 @@ void show_apropos(Fl_Widget *w, void *unused)
 	  Fl_Help_View *br = new Fl_Help_View(1, 1, about->w() - 2, about->h() - 2);
 	  Fl_Button *b = new Fl_Button(1, 1, 1, 1, NULL);//only to allow the shortcut
 	  b->callback(hide_window_callback, NULL);
-	  b->shortcut(myFL_CTRL | 'w');
+	  b->shortcut(FL_COMMAND | 'w');
 	  about->end();
 	  p = get_full_path(get_res_value("helpfile", "seaview.html"));
 	  if(p == NULL) return;
@@ -326,7 +314,6 @@ void show_apropos(Fl_Widget *w, void *unused)
   about->show();
 }
 
-
 void MG_apple_inits(void)
 {
   Fl::set_font(FL_COURIER,"Courier");
@@ -344,49 +331,49 @@ void set_seaview_modified(SEA_VIEW *view, int ismodified)
   [(NSWindow*)(fl_xid(view->dnawin)) setDocumentEdited:ismodified];
 }
 
-#if !__LP64__
-void CtoP(const void *in, void *out)
-{
-  char *vout = (char *)out;
-  int l;
-  if(in == NULL) l = 0;
-  else	{
-	l = strlen( (char *)in );
-	memcpy(vout + 1, in, l);
-  }
-  vout[0] = l;
-}
+#ifdef USE_PICT
+class Fl_PICT_Graphics_Driver : public Fl_Graphics_Driver {
+protected:
+  void rect(int x, int y, int w, int h);
+  void rectf(int x, int y, int w, int h);
+  void line_style(int style, int width, char *dashes=0);
+  void line(int x1, int y1, int x2, int y2);
+  void font(int f, int s);
+  void draw(const char *str, int n, int x, int y);
+  void draw(const char*, int, float, float) ;
+  void draw(int, const char*, int, int, int) ;
+  void rtl_draw(const char*, int, int, int) ;
+  void color(uchar r, uchar g, uchar b);
+  void color(Fl_Color c);
+  void draw_image(const uchar*, int, int, int, int, int, int) ;
+  void draw_image_mono(const uchar*, int, int, int, int, int, int) ;
+  void draw_image(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) ;
+  void draw_image_mono(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) ;
+  void draw(Fl_RGB_Image*, int, int, int, int, int, int) ;
+  void draw(Fl_Pixmap*, int, int, int, int, int, int) ;
+  void draw(Fl_Bitmap*, int, int, int, int, int, int) ;
+  double width(const char*, int) ;
+  int height() ;
+  int descent() ;
+};
 
-
-void MG_fl_draw(const char *txt, int x, int y)
+void Fl_PICT_Graphics_Driver::draw(const char *txt, int n, int x, int y)
 {
-  if(txt == NULL) return;
-  if(!MG_doing_copy){
-	  fl_draw(txt, x, y);
-	  return;
-  }
-  unsigned char copy[strlen(txt) + 1];
-  CtoP(txt, copy);
+  if(txt == NULL || n == 0) return;
   MoveTo(x, y);
+  unsigned char copy[n + 1];
+  memcpy(copy+1, txt, n); *copy = n;
   DrawString(copy);
 }
 
-void MG_fl_line(int x, int y, int x1, int y1)
+void Fl_PICT_Graphics_Driver::line(int x, int y, int x1, int y1)
 {
-  if(!MG_doing_copy){
-	  fl_line(x, y, x1, y1);
-	  return;
-  }
   MoveTo(x, y);
   LineTo(x1, y1);
 }
 
-void MG_fl_rect(int x, int y, int w, int h)
+void Fl_PICT_Graphics_Driver::rect(int x, int y, int w, int h)
 {
-  if(!MG_doing_copy){
-	  fl_rect(x, y, w, h);
-	  return;
-  }
   MoveTo(x, y);
   LineTo(x, y+h-1);
   LineTo(x+w-1, y+h-1);
@@ -394,12 +381,8 @@ void MG_fl_rect(int x, int y, int w, int h)
   LineTo(x, y);
 }
 
-void MG_fl_rectf(int x, int y, int w, int h)
+void Fl_PICT_Graphics_Driver::rectf(int x, int y, int w, int h)
 {
-  if(!MG_doing_copy){
-	  fl_rectf(x, y, w, h);
-	  return;
-  }
   Rect r;
   r.top = (short)y;
   r.left = (short)x;
@@ -408,45 +391,38 @@ void MG_fl_rectf(int x, int y, int w, int h)
   PaintRect(&r);
 }
 
-void MG_fl_font(int fontrank, int size)
+void Fl_PICT_Graphics_Driver::font(int fontrank, int size)
 {
-  if(!MG_doing_copy){
-	  fl_font(fontrank, size);
-	  return;
-  }
   Style mystyle = normal;
   int macfont, fontstyle;
   if(fontrank < FL_SYMBOL) {
-	  fontstyle = fontrank % 4;
-	  fontrank -= fontstyle;
+    fontstyle = fontrank % 4;
+    fontrank -= fontstyle;
   }
   if(fontrank == FL_COURIER)
-	  macfont=kFontIDCourier/*22*/;
+    macfont=kFontIDCourier/*22*/;
   else if(fontrank == FL_HELVETICA)
-	  macfont=kFontIDHelvetica/*21*/;
+    macfont=kFontIDHelvetica/*21*/;
   else if(fontrank == FL_TIMES)
-	  macfont=kFontIDTimes/*20*/;
+    macfont=kFontIDTimes/*20*/;
   else if(fontrank == FL_SYMBOL)
-	  macfont=kFontIDSymbol/*23*/;
+    macfont=kFontIDSymbol/*23*/;
   else
-	  macfont=21; 
+    macfont=21; 
   if(fontrank < FL_SYMBOL) {
-	  if(fontstyle == 0) mystyle = normal;
-	  else if(fontstyle == 1) mystyle = bold;
-	  else if(fontstyle == 2) mystyle = italic;
-	  else if(fontstyle == 3) mystyle = bold+italic;
+    if(fontstyle == 0) mystyle = normal;
+    else if(fontstyle == 1) mystyle = bold;
+    else if(fontstyle == 2) mystyle = italic;
+    else if(fontstyle == 3) mystyle = bold+italic;
   }
   TextFont(macfont);
   TextSize(size);
   TextFace(mystyle);
+  Fl_Display_Device::display_device()->driver()->font(fontrank, size);
 }
 
-void MG_fl_color(Fl_Color color)
+void Fl_PICT_Graphics_Driver::color(Fl_Color color)
 {
-  if(!MG_doing_copy){
-	  fl_color(color);
-	  return;
-  }
   unsigned char r, g, b;
   Fl::get_color(color, r, g, b);
   RGBColor maccolor;
@@ -456,53 +432,74 @@ void MG_fl_color(Fl_Color color)
   RGBForeColor(&maccolor);
 }
 
-float MG_fl_width(char *txt, int l)
+double Fl_PICT_Graphics_Driver::width(const char *txt, int l)
 {
-  if(!MG_doing_copy){
-	  return fl_width(txt, l);
-  }
-  return (float)TextWidth( txt, 0, l );
+  return (double)TextWidth( txt, 0, l );
 }
 
-float MG_fl_width(char *txt)
-{
-	return MG_fl_width(txt, strlen(txt));
+void Fl_PICT_Graphics_Driver::draw_image(const uchar*, int, int, int, int, int, int) {}
+void Fl_PICT_Graphics_Driver::draw_image_mono(const uchar*, int, int, int, int, int, int) {}
+void Fl_PICT_Graphics_Driver::draw_image(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) {}
+void Fl_PICT_Graphics_Driver::draw_image_mono(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) {}
+void Fl_PICT_Graphics_Driver::draw(Fl_RGB_Image*, int, int, int, int, int, int) {}
+void Fl_PICT_Graphics_Driver::draw(Fl_Pixmap*, int, int, int, int, int, int) {}
+void Fl_PICT_Graphics_Driver::draw(Fl_Bitmap*, int, int, int, int, int, int) {}
+void Fl_PICT_Graphics_Driver::line_style(int style, int width, char *dashes) {}
+void Fl_PICT_Graphics_Driver::color(uchar r, uchar g, uchar b) {}
+void Fl_PICT_Graphics_Driver::rtl_draw(const char*, int, int, int) {}
+void Fl_PICT_Graphics_Driver::draw(int angle, const char* str, int n, int x, int y) {}
+int Fl_PICT_Graphics_Driver::height() {
+  return Fl_Display_Device::display_device()->driver()->height();
+}
+int Fl_PICT_Graphics_Driver::descent() {
+  return Fl_Display_Device::display_device()->driver()->descent();
+}
+void Fl_PICT_Graphics_Driver::draw(const char* str, int n, float fx, float fy) {
+  draw(str, n, (int)fx, (int)fy);
 }
-#endif
 
+#endif // USE_PICT
 
-void *MG_PrepareCopy(int w, int h)
+Fl_Copy_Surface::Fl_Copy_Surface(bool pict, int w, int h) : Fl_Surface_Device(NULL)
 {
-#if __LP64__
-  return prepare_copy_pdf_and_pict(w, h);
+#ifdef USE_PICT
+  use_pict = pict;
 #else
-  Rect myrect;
-  myrect.top=0;
-  myrect.left=0;
-  myrect.right=w;
-  myrect.bottom=h;
-  PicHandle mypicture = OpenPicture(&myrect);
-  ClipRect(&myrect);
-  PenNormal();
-  MG_doing_copy = 1;
-  return mypicture;
+  use_pict = false;
 #endif
+  if (use_pict) {
+#ifdef USE_PICT
+      Rect myrect;
+      myrect.top=0;
+      myrect.left=0;
+      myrect.right=w;
+      myrect.bottom=h;
+      mypicture = OpenPicture(&myrect);
+      ClipRect(&myrect);
+      PenNormal();
+      driver(new Fl_PICT_Graphics_Driver());
+#endif
+    }
+  else {
+    data = prepare_copy_pdf_and_pict(w, h);
+    driver(new Fl_Quartz_Graphics_Driver());
+    }
 }
 
-
-void MG_CompleteCopy(void *mypicture)
+Fl_Copy_Surface::~Fl_Copy_Surface()
 {
-#if __LP64__
-  complete_copy_pdf_and_pict(mypicture);
-#else
-  ClosePicture();
-  MG_doing_copy = 0;
-  MyCopyPictToClipboard((PicHandle)mypicture);
-  KillPicture((PicHandle)mypicture);
+  if (use_pict) {
+#ifdef USE_PICT
+      ClosePicture();
+      MyCopyPictToClipboard(mypicture);
+      KillPicture(mypicture);
 #endif
+    }
+  else
+    complete_copy_pdf_and_pict(data);
+  delete driver();
 }
 
-
 static size_t MyPutBytes (void* info, const void* buffer, size_t count)
 {
   CFDataAppendBytes ((CFMutableDataRef) info, (const UInt8 *)buffer, count);
@@ -510,7 +507,7 @@ static size_t MyPutBytes (void* info, const void* buffer, size_t count)
 }
 
 
-#if !__LP64__
+#ifdef USE_PICT
 QDPictRef MyPictToQDPict(PicHandle mypicture)
 {
   CFIndex pictlen;
@@ -583,7 +580,7 @@ void MyCopyPictToClipboard (PicHandle mypicture)
   CFRelease (clipboard);
   if(myqdpict != NULL) QDPictRelease(myqdpict);
 }
-#endif
+#endif // USE_PICT
 
 //next 2 functions copy quartz data to clipboard both as pdf and as PICT (or tiff for 64-bit) bitmap
 void *prepare_copy_pdf_and_pict(int w, int h)
@@ -624,7 +621,7 @@ void complete_copy_pdf_and_pict(void *data)
 						   pdfdata, kPasteboardFlavorNoFlags);
   
   
-  //second, transform this PDF to a bitmap image and put it as PICT/jpeg in clipboard
+  //second, transform this PDF to a bitmap image and put it as PICT/tiff in clipboard
   CGDataProviderRef prov;
   if(fl_mac_os_version >= 100400) { // true from 10.4
     prov = CGDataProviderCreateWithCFData(pdfdata);
@@ -650,15 +647,22 @@ void complete_copy_pdf_and_pict(void *data)
   CGRect rect = CGRectMake(0, 0, w, h);
   CGContextSetRGBFillColor(fl_gc,  1,1,1,1);//need to clear background
   CGContextFillRect(fl_gc, rect);
-  CGContextDrawPDFDocument(fl_gc, rect, pdfdoc, 1);
+#if MAC_OS_X_VERSION_MAX_ALLOWED >= 1030
+  if (CGContextDrawPDFPage) {
+    CGContextConcatCTM(fl_gc, CGAffineTransformMakeScale(scale, scale));
+    CGContextDrawPDFPage(fl_gc, pdfpage);  // 10.3
+    }
+  else
+#endif
+    CGContextDrawPDFDocument(fl_gc, rect, pdfdoc, 1);
   CGPDFDocumentRelease(pdfdoc);
   CFRelease(pdfdata);
   if(fl_mac_os_version >= 100400) {// way for >= 10.4 that doesn't use QuickTime:
     CFMutableDataRef pictdata = CFDataCreateMutable(NULL, 0);
-#if __LP64__
-    CFStringRef  uti = CFSTR("public.tiff");
-#else
+#ifdef USE_PICT
     CFStringRef  uti = CFSTR("com.apple.pict");
+#else
+    CFStringRef  uti = CFSTR("public.tiff");
 #endif
     CGImageRef image = CGBitmapContextCreateImage(fl_gc);
     CGImageDestinationRef dest = CGImageDestinationCreateWithData(pictdata, uti, 1, NULL);
@@ -666,7 +670,7 @@ void complete_copy_pdf_and_pict(void *data)
     CGImageDestinationFinalize(dest);
     CGImageRelease(image);
     CFRelease(dest);
-#if !__LP64__
+#ifdef USE_PICT
     CFRange range = CFRangeMake(0, 512);
     CFDataDeleteBytes(pictdata, range);// The PICT clipboard REQUIRES only the image data, not the header.
 #endif
