@@ -738,17 +738,92 @@ return build_list_pairs(in, max_chars);
 }
 
 
+int process_translate(FILE *in, char ***ptaxnames)
+{
+  char *p, **taxnames;
+  int rank;
+  
+  taxnames = (char **) malloc(10000*sizeof(char*));
+  while (TRUE)
+  {
+    p = next_token(in);
+    if (*p == ',') continue;
+    if (*p == ';') break;
+    sscanf(p, "%d", &rank);
+    p = next_token(in);
+    taxnames[rank - 1] = strdup(p);
+    }
+  taxnames = (char **)realloc(taxnames, rank * sizeof(char*));
+  *ptaxnames = taxnames;
+  return rank;
+}
+
+char *replace_ranks_by_names(char *tree, int ntaxa, char **taxnames)
+{
+  char *p = tree, *q, *r;
+  char *newtree;
+  char bootstrap_comment[300];
+  int rank, l;
+  float pp;
+  
+  l = strlen(tree);
+  for (int i = 0; i < ntaxa; i++) {
+    l += strlen(taxnames[i]);
+    }
+  newtree = (char*)malloc(l);
+  q = newtree;
+  while (TRUE) {
+    if (*p == ';') break;
+    if (*p == '[') { // skip comments
+      do p++; while (*p != ']');
+      p++;
+      continue;
+    }
+    if (*p == ')' && *(p+1) == '[') { // a comment with a PP value
+      *q++ = *p++;
+      r = bootstrap_comment;
+      do *r++ = *p++; while (*p != ']');
+      p++;
+      *r = 0;
+      if ( strncmp(bootstrap_comment, "[&prob=", 7) == 0) {
+	sscanf(bootstrap_comment + 7, "%f", &pp);
+	sprintf(q, "%.2f", pp);
+	q += strlen(q);
+	}
+      continue;
+      }
+    if ( (*p == '(' || *p == ',') && isdigit(*(p+1))) { // a taxon rank is found
+      *q++ = *p++;
+      sscanf(p, "%d", &rank);
+      sprintf(q, "%s", taxnames[rank - 1]);
+      q += strlen(q);
+      p++;
+      while (isdigit(*p)) p++;
+      continue;
+      }
+    *q++ = *p++;
+    }
+  *q++ = ';';
+  *q = 0;
+  free(tree);
+  newtree = (char *)realloc(newtree, (q - newtree) + 1);
+  return newtree;
+}
+
 int process_block_trees(FILE *in, char ***ptrees, char ***pnames)
 {
-	char **trees, **names;
+	char **trees, **names, **taxnames;
 	char *p;
-	int maxi = 5;
+	int maxi = 5, ntaxa = 0;
 	trees = (char **)calloc(maxi, sizeof(char *));
 	names = (char **)calloc(maxi, sizeof(char *));
 	int count = 0;
 	while(TRUE) {
 		p = next_token(in);
 		if(is_block_end(p)) break;
+		if(strcmp(p, "TRANSLATE") == 0) {
+		  ntaxa = process_translate(in, &taxnames);
+		  }
 		if(strcmp(p, "TREE") == 0) {
 			if(count >= maxi) {
 				maxi += 5;
@@ -759,15 +834,15 @@ int process_block_trees(FILE *in, char ***ptrees, char ***pnames)
 			next_token(in);//skip =
 			trees[count] = (char *)malloc(500000);
 			p = trees[count];
-			do *p = fgetc(in); while(isspace(*p));
-			p++;
+			*p++ = *next_token(in);
 			while(TRUE) {
-				*p = fgetc(in);
-				if(*p == '\n' || *p == '\r') continue;
-				if(*p++ == ';') break;
-				}
+			  *p = fgetc(in);
+			  if(*p == '\n' || *p == '\r') continue;
+			  if(*p++ == ';') break;
+			  }
 			*p = 0;
 			trees[count] = (char *)realloc(trees[count] , p - trees[count] + 1);
+		  if (ntaxa > 0) trees[count] = replace_ranks_by_names(trees[count], ntaxa, taxnames);
 			count++;
 			}
 		}
@@ -775,6 +850,10 @@ int process_block_trees(FILE *in, char ***ptrees, char ***pnames)
 	names = (char **)realloc(names, count * sizeof(char *));
 	*ptrees = trees;
 	*pnames = names;
+  if (ntaxa > 0) {
+    for (int i = 0; i < ntaxa; i++) free(taxnames[i]);
+    free(taxnames);
+    }
 	return count;
 }
 
