@@ -2,23 +2,12 @@
 #include "treedraw.h"
 #include <time.h>
 #include "FL/Fl_Native_File_Chooser.H"
+#include "FL/Fl_Paged_Device.H"
 #include <ctype.h>
 
-PDF *pdf = NULL;
-int pdf_font;
-int pdf_font_size;
+static PDF *pdf = NULL;
 
-extern int printout_block, printout_fontsize, printout_black, printout_vary;
-extern paperformat printout_pageformat;
 extern char *prepare_ps_or_pdf_font(int font_num);
-extern paperformat printout_pageformat;
-extern int pdf_or_ps_plot, ps_width; 
-extern double physx, physy, maxx, nexty;
-extern char *end_br_length;
-extern void mem_plot(FD_nj_plot *fd_nj_plot, struct noeud *pere, struct noeud *centre, double currx,
-			  double *curry);
-extern void do_plot(FD_nj_plot *fd_nj_plot, int doing_print);
-
 
 int pdf_printout(SEA_VIEW *view, const char *filename, 
 	int fontsize, int block_size, paperformat pageformat, int vary_only, int ref0, int pdfkindvalue);
@@ -26,7 +15,6 @@ static void color_pdf_display(PDF *pdf, SEA_VIEW *view, int (*calc_color_functio
 	int widnames, double x, double y, int fontsize, double char_width, double descender,int num, int current);
 static int calc_vary_lines(int *vary_pos, int widpos);
 static void out_vary_pos(int *vary_pos, int widnames, int widpos, int nl, PDF *pdf, FILE *textfile);
-void pdf_tree_plot(FD_nj_plot *fd_nj_plot);
 
 
 int pdf_printout(SEA_VIEW *view, const char *filename, 
@@ -363,128 +351,269 @@ for(l = nl; l > 0; l--) {
 }
 
 
-void pdf_tree_plot(FD_nj_plot *fd_nj_plot)
+class Fl_PDF_Graphics_Driver : public Fl_Graphics_Driver {
+private:
+  PDF *pdf;
+  int pdf_font;
+  const char *encoding;
+  bool in_page;
+public:
+  Fl_PDF_Graphics_Driver();
+protected:
+  void rect(int x, int y, int w, int h);
+  void rectf(int x, int y, int w, int h);
+  void line_style(int style, int width, char *dashes=0);
+  void line(int x1, int y1, int x2, int y2);
+  void font(int f, int s);
+  void draw(const char *str, int n, int x, int y);
+  void draw(const char*, int, float, float) ;
+  void draw(int, const char*, int, int, int) ;
+  void rtl_draw(const char*, int, int, int) ;
+  void color(uchar r, uchar g, uchar b);
+  void color(Fl_Color c);
+  void push_clip(int x, int y, int w, int h) ;
+  void pop_clip();
+  void draw_image(const uchar*, int, int, int, int, int, int) ;
+  void draw_image_mono(const uchar*, int, int, int, int, int, int) ;
+  void draw_image(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) ;
+  void draw_image_mono(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) ;
+  void draw(Fl_RGB_Image*, int, int, int, int, int, int) ;
+  void draw(Fl_Pixmap*, int, int, int, int, int, int) ;
+  void draw(Fl_Bitmap*, int, int, int, int, int, int) ;
+  double width(const char*, int) ;
+  int height() ;
+  int descent() ;
+friend class Fl_PDF_File_Device;
+};
+
+
+Fl_PDF_File_Device::Fl_PDF_File_Device()
 {
-	int t_font;
-	const char *encoding;
-	FILE *f;
-	
-	double currx, curry;
-	int page, offset;
-	double paper_h; 
-	int sheets_h, recouvre;
-	const int a4_h = 750, letter_h = 700;
-	time_t heure;
-	/* partie dessinable 500(ps_width) x a4_h decalee de 50 x 50 par rapport a coin inferieur gauche du papier
-	 cadre exterieur de 10 sur les 4 cotes, correspond aussi a zone de clip
-	 */
-	char bigline[500];
-#ifdef WIN_MAC
-    encoding	= "macroman";
-#else
-    encoding	= "iso8859-1";
-#endif
-	
-	if(fd_nj_plot->notu == 0) return;
-	Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
-	chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
-	chooser->title("Set PDF filename");       
-  chooser->filter("PDF Files\t*.pdf");
-	char tmp[100];
-	strcpy(tmp, extract_filename(fd_nj_plot->tree_name));
-	char *p = strrchr(tmp, '.'); if(p != NULL) *p = 0;
-	strcat(tmp, ".pdf");
-	chooser->preset_file(tmp);
-	char *plotfilename = run_and_close_native_file_chooser(chooser);
-	if(plotfilename == NULL) return;
-	if( (f = fopen(plotfilename, "r")) != NULL) {
-		fclose(f);
-		if(fl_choice("File %s already exists.", "Cancel", "Overwrite", NULL, plotfilename) == 0) return;
-		}
-	
-	pdf = PDF_new();
-	if(pdf == NULL) return;
-	
-	if( PDF_begin_document(pdf, plotfilename, 0, "compatibility=1.3") == -1) {
-		PDF_delete(pdf);
-		fl_alert("Error opening %s for writing\n", plotfilename);
-		return;
-	}
-	char *current_ps_font = prepare_ps_or_pdf_font(fd_nj_plot->font_family);
-	PDF_TRY(pdf) {
-		
-		PDF_set_info(pdf, "Title", fd_nj_plot->tree_name );
-		PDF_set_info(pdf, "Creator", "seaview");
-		t_font = PDF_load_font(pdf, "Times-Roman", 0, encoding, "");
-		pdf_font = PDF_load_font(pdf, current_ps_font, 0, encoding, "");
-		pdf_font_size = fd_nj_plot->font_size;
-		
-		if(printout_pageformat == A4) { paper_h = a4_h; }
-		else /* LETTER */ { paper_h = letter_h; }
-		
-		my_watch_cursor(fd_nj_plot->full->window());
-		pdf_or_ps_plot = TRUE;
-		
-		/* recouvre = paper_h / 30; */
-		recouvre = 0;
-		sheets_h = ((int)paper_h - recouvre) * fd_nj_plot->page_count + recouvre;
-		offset = (int)paper_h - recouvre;
-		physx = ps_width;
-		physy = sheets_h;
-		
-		time(&heure);
-		
-		fd_nj_plot->totnoms = fd_nj_plot->tottraits = fd_nj_plot->totpoints = -1;
-		end_br_length = fd_nj_plot->br_length_txt;
-		currx = 0.;
-		maxx = 0.;
-		nexty = -fd_nj_plot->deltay;
-		if(fd_nj_plot->subtree_center == NULL)
-			mem_plot(fd_nj_plot, NULL, fd_nj_plot->racine, currx, &curry);
-		else
-			mem_plot(fd_nj_plot, fd_nj_plot->subtree_ascend, fd_nj_plot->subtree_center, currx, &curry);
-		for(page = 0; page < fd_nj_plot->page_count ; page++) {
-			PDF_begin_page_ext(pdf, 
-							   printout_pageformat == A4 ? a4_width : letter_width,
-							   printout_pageformat == A4 ? a4_height : letter_height,
-							   "");
-			PDF_setfont(pdf, t_font, 12);
-			sprintf(bigline, "%s  %s  Page %d of %d", extract_filename(fd_nj_plot->tree_name), ctime(&heure), page+1, fd_nj_plot->page_count);
-			PDF_show_xy(pdf, bigline, 40, paper_h+65);
-			
-			PDF_setlinecap(pdf, 1);
-			PDF_setlinewidth(pdf, 1);
-			PDF_moveto(pdf, 40, 40); PDF_lineto(pdf, ps_width + 60, 40); PDF_lineto(pdf, ps_width + 60, paper_h+60);
-			PDF_lineto(pdf, 40, paper_h+60); 
-			PDF_closepath(pdf); PDF_clip(pdf);
-			PDF_translate(pdf, 0, - (fd_nj_plot->page_count - page - 1) * offset);
-			PDF_setfont(pdf, pdf_font, pdf_font_size);
-			PDF_translate(pdf, 50, 50);
-			PDF_setcolor(pdf, "stroke", "gray", 0.7, 0,0,0);
-			PDF_moveto(pdf, -10, -10); 
-			PDF_lineto(pdf, ps_width + 10, -10); 
-			PDF_lineto(pdf, ps_width + 10, sheets_h+10); 
-			PDF_lineto(pdf, -10, sheets_h+10); 
-			PDF_closepath_stroke(pdf); 
-			PDF_setcolor(pdf, "stroke", "gray", 0, 0,0,0);
-			do_plot(fd_nj_plot, TRUE);
-			PDF_end_page_ext(pdf, "");
-		}
-		PDF_end_document(pdf, "");
-		PDF_delete(pdf);
-	} /* end of PDF_TRY */
-	PDF_CATCH(pdf) {
-		fl_reset_cursor(fd_nj_plot->full->window());
-		fl_alert("Error while writing pdf file: [%d] %s: %s",
-				 PDF_get_errnum(pdf), PDF_get_apiname(pdf), PDF_get_errmsg(pdf));
-        PDF_delete(pdf);
-		pdf_or_ps_plot = FALSE;
-        return; 
-	}
-	
-	fd_nj_plot->need_runtree = TRUE;
-	pdf_or_ps_plot = FALSE;
-	fl_reset_cursor(fd_nj_plot->full->window());
-	fl_alert("Tree plot is now in file %s in PDF format", extract_filename(plotfilename));
+  driver(new Fl_PDF_Graphics_Driver);
+  filename = NULL;
 }
 
+Fl_PDF_File_Device::~Fl_PDF_File_Device()
+{
+  delete driver();
+}
+
+int Fl_PDF_File_Device::start_job(const char *name, enum Fl_Paged_Device::Page_Format format, 
+	      enum Fl_Paged_Device::Page_Layout layout)
+{
+  Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
+  chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
+  chooser->title("Set PDF filename");       
+  chooser->filter("PDF Files\t*.pdf");
+  int l = name ? strlen(name) : 0;
+  char *preset = new char[l + 5];
+  strcpy(preset, name ? name : "" );
+  char *p = strchr(preset, '.');
+  if (p) *p = 0;
+  strcat(preset, ".pdf");
+  chooser->preset_file(preset);
+  delete[] preset;
+  chooser->options(Fl_Native_File_Chooser::SAVEAS_CONFIRM);
+  char *plotfilename = run_and_close_native_file_chooser(chooser);
+  if(plotfilename == NULL) return 1;
+#ifdef WIN32
+  FILE *f;
+  if( (f = fopen(plotfilename, "r")) != NULL) {
+    fclose(f);
+    if(fl_choice("File %s already exists.", "Cancel", "Overwrite", NULL, plotfilename) == 0) return 1;
+  }
+#endif
+  width = page_formats[format].width;
+  height = page_formats[format].height;
+  PDF *pdf = PDF_new();
+  if(pdf == NULL) return 1;
+  Fl_PDF_Graphics_Driver *d = (Fl_PDF_Graphics_Driver*)driver();
+  d->pdf = pdf;
+  if( PDF_begin_document(pdf, plotfilename, 0, "compatibility=1.3") == -1) {
+    PDF_delete(pdf);
+    fl_alert("Error opening %s for writing\n", plotfilename);
+    return 1;
+  }
+  PDF_set_info(pdf, "Title", plotfilename );
+  PDF_set_info(pdf, "Creator", "seaview");
+  previous_surface = Fl_Surface_Device::surface();
+  if (format == Fl_Paged_Device::A4) {
+    left_margin = 18;
+    top_margin = 18;
+  }
+  else {
+    left_margin = 12;
+    top_margin = 12;
+  }
+  filename = strdup(plotfilename);
+  set_current();
+  return 0;
+}
+
+PDF *Fl_PDF_File_Device::pdf()
+{
+  return ((Fl_PDF_Graphics_Driver*)driver())->pdf;
+}
+
+int Fl_PDF_File_Device::start_page()
+{
+  Fl_PDF_Graphics_Driver *d = (Fl_PDF_Graphics_Driver*)driver();
+  PDF *p = d->pdf;
+  PDF_begin_page_ext(p, width, height, "");
+  PDF_translate(p, left_margin, height - top_margin);
+  PDF_scale(p, 1, -1);
+  PDF_setlinecap(p, 1);
+  PDF_setlinewidth(p, 1);
+  d->in_page = true;
+  return 0;
+}
+
+int Fl_PDF_File_Device::printable_rect(int *w, int *h)
+//returns 0 iff OK
+{
+  if(w) *w = (int)((width - 2 * left_margin) + .5);
+  if(h) *h = (int)((height - 2 * top_margin) + .5);
+  return 0;
+}
+
+int Fl_PDF_File_Device::end_page()
+{
+  Fl_PDF_Graphics_Driver *d = (Fl_PDF_Graphics_Driver*)driver();
+  PDF_end_page_ext(d->pdf, "");
+  d->in_page = false;
+  return 0;
+}
+
+void Fl_PDF_File_Device::end_job()
+{
+  PDF *p = ((Fl_PDF_Graphics_Driver*)driver())->pdf;
+  PDF_end_document(p, "");
+  PDF_delete(p);
+  if (filename) free(filename);
+  filename = NULL;
+  previous_surface->set_current();
+}
+
+void Fl_PDF_File_Device::error_catch()
+{
+  PDF *p = ((Fl_PDF_Graphics_Driver*)driver())->pdf;
+  Fl_Display_Device::display_device()->set_current();
+  fl_alert("Error while writing to pdf file:\n%s", filename);
+  PDF_delete(p);
+  if (filename) free(filename);
+  filename = NULL;
+}
+
+Fl_PDF_Graphics_Driver::Fl_PDF_Graphics_Driver()
+{
+#ifdef __APPLE__
+  encoding	= "macroman";
+#else
+  encoding	= "iso8859-1";
+#endif
+  pdf = NULL;
+  pdf_font = -1;
+  in_page = false;
+}
+
+void Fl_PDF_Graphics_Driver::line(int x1, int y1, int x2, int y2)
+{
+  PDF_moveto(pdf, x1, y1);
+  PDF_lineto(pdf, x2, y2);
+  PDF_stroke(pdf);
+}
+
+void Fl_PDF_Graphics_Driver::rect(int x, int y, int w, int h)
+{
+  PDF_rect(pdf, x, y, w, h);
+  PDF_stroke(pdf);
+}
+
+void Fl_PDF_Graphics_Driver::rectf(int x, int y, int w, int h)
+{
+  PDF_rect(pdf, x, y, w, h);
+  PDF_fill(pdf);
+}
+
+void Fl_PDF_Graphics_Driver::draw(const char *str, int n, int x, int y)
+{
+  PDF_save(pdf);
+  PDF_translate(pdf, x, y);
+  PDF_scale(pdf, 1, -1);
+  PDF_show_xy2(pdf, str, n, 0, 0);
+  PDF_restore(pdf);
+}
+
+void Fl_PDF_Graphics_Driver::draw(int angle, const char* str, int n, int x, int y)
+{
+  PDF_save(pdf);
+  PDF_translate(pdf, x, y);
+  PDF_rotate(pdf, -angle);
+  draw(str, n, 0, 0);
+  PDF_restore(pdf);
+}
+
+void Fl_PDF_Graphics_Driver::font(int f, int s)
+{
+  char *current_ps_font = prepare_ps_or_pdf_font(f);
+  pdf_font = PDF_load_font(pdf, current_ps_font, 0, encoding, "");
+  Fl_Graphics_Driver::font(f, s);
+  if (in_page) PDF_setfont(pdf, pdf_font, s);
+}
+
+void Fl_PDF_Graphics_Driver::color(Fl_Color c)
+{
+  uchar red, green, blue;
+  Fl::get_color(c, red, green, blue);
+  color(red, green, blue);
+}
+
+void Fl_PDF_Graphics_Driver::color(uchar red, uchar green, uchar blue)
+{
+  float r, g, b;
+  r = red/255.; g = green/255.; b = blue/255.;
+  PDF_setcolor(pdf, "fillstroke", "rgb", r, g, b, 0);
+}
+
+double Fl_PDF_Graphics_Driver::width(const char* str, int l)
+{
+  return PDF_stringwidth2(pdf, str, l, pdf_font, size());
+}
+
+int Fl_PDF_Graphics_Driver::height() {
+  return size();
+}
+
+int Fl_PDF_Graphics_Driver::descent() {
+  return (int)(-PDF_get_value(pdf, "descender", pdf_font) * size() + 0.5) + 1;
+}
+
+void Fl_PDF_Graphics_Driver::draw(const char* str, int n, float fx, float fy) {
+  draw(str, n, (int)fx, (int)fy);
+}
+
+void Fl_PDF_Graphics_Driver::push_clip(int x, int y, int w, int h) 
+{
+  PDF_save(pdf);
+  PDF_moveto(pdf, x, y); PDF_lineto(pdf, x + w, y); PDF_lineto(pdf, x + w, y + h);
+  PDF_lineto(pdf, x, y + h); 
+  PDF_closepath(pdf); 
+  PDF_clip(pdf);
+}
+
+void Fl_PDF_Graphics_Driver::pop_clip()
+{
+  PDF_restore(pdf);
+}
+
+void Fl_PDF_Graphics_Driver::draw_image(const uchar*, int, int, int, int, int, int) {}
+void Fl_PDF_Graphics_Driver::draw_image_mono(const uchar*, int, int, int, int, int, int) {}
+void Fl_PDF_Graphics_Driver::draw_image(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) {}
+void Fl_PDF_Graphics_Driver::draw_image_mono(void (*)(void*, int, int, int, uchar*), void*, int, int, int, int, int) {}
+void Fl_PDF_Graphics_Driver::draw(Fl_RGB_Image*, int, int, int, int, int, int) {}
+void Fl_PDF_Graphics_Driver::draw(Fl_Pixmap*, int, int, int, int, int, int) {}
+void Fl_PDF_Graphics_Driver::draw(Fl_Bitmap*, int, int, int, int, int, int) {}
+void Fl_PDF_Graphics_Driver::line_style(int style, int width, char *dashes) {}
+void Fl_PDF_Graphics_Driver::rtl_draw(const char*, int, int, int) {}
+
+
