@@ -2,20 +2,6 @@
 #include <time.h>
 #include <ctype.h>
 
-extern int printout_block, printout_fontsize, printout_black, printout_vary;
-extern paperformat printout_pageformat;
-extern char *prepare_ps_or_pdf_font(int font_num);
-extern paperformat printout_pageformat;
-extern int pdf_or_ps_plot, ps_width; 
-extern double physx, physy, maxx, nexty;
-extern char *end_br_length;
-extern float postscript_ratio;
-extern FILE *plotfile;
-extern void mem_plot(FD_nj_plot *fd_nj_plot, struct noeud *pere, struct noeud *centre, double currx,
-					 double *curry);
-extern void do_plot(FD_nj_plot *fd_nj_plot, int doing_print);
-
-
 int postscript_printout(SEA_VIEW *view, const char *filename, 
 	int fontsize, int block_size, paperformat pageformat, int vary_only, int ref0, int blackonly);
 static void color_ps_display(FILE *psout, SEA_VIEW *view, int (*calc_color_function)( int ), char *oneline, 
@@ -23,7 +9,6 @@ static void color_ps_display(FILE *psout, SEA_VIEW *view, int (*calc_color_funct
 static int calc_vary_lines(int *vary_pos, int widpos);
 static void out_vary_pos(int *vary_pos, int widnames, int widpos, int nl, FILE *psout, 
 	int x, int y, int yoffset);
-void postscript_tree_plot(FD_nj_plot *fd_nj_plot);
 
 
 int postscript_printout(SEA_VIEW *view, const char *filename, 
@@ -329,134 +314,3 @@ for(l = nl; l > 0; l--) {
 	echelle /= 10;
 	}
 }
-
-void postscript_tree_plot(FD_nj_plot *fd_nj_plot)
-{
-	double currx, curry;
-	int page, erreur = FALSE, offset;
-	int paper_h, sheets_h, recouvre, page_h, page_w;
-  const int a4_h = 750, letter_h = 700; // printable height
-  const int a4_hh = 842, letter_hh = 792; // full page height
-  const int a4_ww = 595, letter_ww = 612; // full page width
-	time_t heure;
-	float screen_w, ps_w;
-	static int first = TRUE;
-	const char alphabet[]="ABCDEFGHIJKLMNOPQRSTUVWXYZ";
-	FILE *f;
-	/* partie dessinable 500(ps_width) x a4_h decalee de 50 x 50 par rapport a coin inferieur gauche du papier
-	 cadre exterieur de 10 sur les 4 cotes, correspond aussi a zone de clip
-	 */
-	
-	if(fd_nj_plot->notu == 0) return;
-	if(printout_pageformat == A4) {
-	  paper_h = a4_h;
-	  page_h = a4_hh;
-	  page_w = a4_ww;
-	}
-	else {
-	  paper_h = letter_h;
-	  page_h = letter_hh;
-	  page_w = letter_ww;
-	}
-	
-	Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
-	chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
-	chooser->title("Set PostScript filename");       
-  chooser->filter("PostScript Files\t*.ps");
-	char tmp[100];
-	strcpy(tmp, extract_filename(fd_nj_plot->tree_name));
-	char *p = strrchr(tmp, '.'); if(p != NULL) *p = 0;
-	strcat(tmp, ".ps");
-	chooser->preset_file(tmp);
-	char *plotfilename = run_and_close_native_file_chooser(chooser);
-	if(plotfilename == NULL) return;
-	if( (f = fopen(plotfilename, "r")) != NULL) {
-		fclose(f);
-		if(fl_choice("File %s already exists.", "Cancel", "Overwrite", NULL, plotfilename) == 0) return;
-	}
-	
-	if(first) {
-		first = FALSE;
-		fl_font(FL_COURIER, 12);
-		screen_w = fl_width(alphabet);/*taille sur ecran*/
-		ps_w = 12 * 0.60 * 26; /*taille en postscript pour courier,12*/
-		postscript_ratio = ps_w / screen_w ;
-	}
-	/* recouvre = paper_h / 30; */
-	recouvre = 0;
-	sheets_h = (paper_h - recouvre) * fd_nj_plot->page_count + recouvre;
-	offset = paper_h - recouvre;
-	physx = ps_width;
-	physy = sheets_h;
-	
-	
-	plotfile=fopen(plotfilename,"w");
-	if(plotfile == NULL) {
-		fl_alert("Error opening %s for writing\n", plotfilename);
-		return;
-	}
-	pdf_or_ps_plot = TRUE;
-	my_watch_cursor(fd_nj_plot->full->window());
-	char *current_ps_font = prepare_ps_or_pdf_font(fd_nj_plot->font_family);
-	fprintf(plotfile,"%%!PS-Adobe-1.0\n"
-			"%%%%DocumentFonts: Times-Roman %s\n"
-			"%%%%Creator: seaview\n"
-			"%%%%Pages: %d\n"
-			"%%%%Title: %s\n"
-			"%%%%BeginFeature: *PageSize %s\n"
-		"<</PageSize[%d %d]>>setpagedevice\n"
-			"%%%%EndFeature\n"
-			"%%%%EndComments\n",
-			current_ps_font, fd_nj_plot->page_count, fd_nj_plot->tree_name, 
-    printout_pageformat == A4 ? "A4" : "Letter", page_w, page_h );
-	fprintf(plotfile,
-			"/setpacking where {true setpacking} if\n"
-			"1 setlinecap 1 setlinejoin 1 setlinewidth 0 setgray\n"
-			"/basefont /%s findfont %d scalefont def\n",
-			current_ps_font, fd_nj_plot->font_size);
-	fprintf(plotfile,"/titlefont /Times-Roman findfont 12 scalefont def\n");
-	fprintf(plotfile, "/setclip {40 40 moveto %d 40 lineto %d %d lineto 40 %d "
-			"lineto closepath clip newpath} def\n", 
-			ps_width + 60, ps_width + 60, paper_h+60, paper_h+60);
-	time(&heure);
-	fprintf(plotfile, "/title {titlefont setfont\n"
-			"40 %d moveto (%s   %s) show (  Page ) show show ( of %d) show\n"
-			"} def\n", 
-			paper_h+65, extract_filename(fd_nj_plot->tree_name), ctime(&heure), fd_nj_plot->page_count);
-	fprintf(plotfile,"%%%%EndProlog\n");
-	
-	fd_nj_plot->totnoms = fd_nj_plot->tottraits = fd_nj_plot->totpoints = -1;
-	end_br_length = fd_nj_plot->br_length_txt;
-	currx = 0.;
-	maxx = 0.;
-	nexty = -fd_nj_plot->deltay;
-	fl_font(fd_nj_plot->font_family, fd_nj_plot->font_size);/*retour a police courante pour ecran */
-	if(fd_nj_plot->subtree_center == NULL)
-		mem_plot(fd_nj_plot, NULL, fd_nj_plot->racine, currx, &curry);
-	else
-		mem_plot(fd_nj_plot, fd_nj_plot->subtree_ascend, fd_nj_plot->subtree_center, currx, &curry);
-	for(page = 0; page < fd_nj_plot->page_count ; page++) {
-		fprintf(plotfile,"%%%%Page: ? %d\n", page+1);
-	  fprintf(plotfile, "%%%%PageBoundingBox: 0 0 %d %d\n", page_w, page_h);
-		fprintf(plotfile,"(%d) title ", page+1);
-		fprintf(plotfile,"setclip\n");
-		fprintf(plotfile,"0 %d translate\n", - (fd_nj_plot->page_count - page - 1) * offset);
-		fprintf(plotfile,"basefont setfont\n");
-		fprintf(plotfile,"50 50 translate\n");
-		fprintf(plotfile,"0.7 setgray -10 -10 moveto %d -10 lineto %d %d lineto "
-				"-10 %d lineto closepath stroke 0 setgray \n", 
-				ps_width + 10, ps_width + 10, sheets_h+10, sheets_h+10);
-		do_plot(fd_nj_plot, TRUE);
-		fprintf(plotfile,"showpage\n");
-	}
-	fprintf(plotfile, "%%%%Trailer\n");
-	if(ferror(plotfile)) erreur = TRUE;
-	if(fclose(plotfile) != 0) erreur = TRUE;
-	
-	fd_nj_plot->need_runtree = TRUE;
-	pdf_or_ps_plot = FALSE;
-	fl_reset_cursor(fd_nj_plot->full->window());
-	if(erreur  ) fl_alert("Error while writing to file %s", extract_filename(plotfilename) );
-}
-
-
