@@ -254,7 +254,7 @@ if(load_form == NULL) {
 
 	Fl_Button *close = new Fl_Button(390, 160, 55, 20 , "Close");
 	close->callback(hide_window_callback, NULL);
-	close->shortcut(myFL_CTRL | 'w');
+	close->shortcut(FL_COMMAND | 'w');
 	
 	Fl_Check_Button *more = new Fl_Check_Button(5, 160, 135, 20 , "More Databases");
 	more->callback(more_callback, &raa_fields);
