@@ -1,11 +1,12 @@
 #include "seaview.h"
 #include <FL/Fl_Round_Button.H>
+#include <FL/Fl_Check_Button.H>
 #include <ctype.h>
 
 
-enum position_mask {custom_mask = -1, position_1, position_2, position_3, position_12,
-  variable_sites };
-const char *position_mask_names[] = {"First codon pos.", "Second codon pos.",
+enum position_mask {custom_mask = -1, gblocks_sites, position_1, position_2, position_3, position_12,
+  variable_sites  };
+const char *position_mask_names[] = {"Gblocks", "First codon pos.", "Second codon pos.",
 "Third codon pos.", "1st+2nd codon pos.", "Variable sites"};
 int position_mask_count = sizeof(position_mask_names)/sizeof(char*);
 
@@ -49,6 +50,10 @@ int parse_species_sets_from_header(char *header, int **list_species_sets,
 
 extern void adjust_menu_edit_modes(SEA_VIEW *view);
 int compute_size_params(SEA_VIEW *view, int force_recompute);
+extern char *create_tmp_filename(void);
+extern int save_fasta_file(const char *fname, char **seq, char **comments,
+			   char **seqname, int totseqs, int *eachlength, region *region_used,
+			   int *sel_seqs, int tot_sel_seqs, int spaces_in_names);
 
 
 region *duplicate_region(region *source, const char *name)
@@ -191,8 +196,159 @@ void create_variable_mask(SEA_VIEW *view, region *maregion)
     }
 }
 
+int create_gblocks_mask(SEA_VIEW *view, region *maregion)
+/* return 0 iff OK */
+{
+  char cmd[500];
+  char base_fname[150], fname[150], *p, *q, *last;
+  int status, segment_count = -1, num, l;
+  FILE *in;
+  list_segments *segment, *previous;
+  Fl_Widget *o;
+  
+  q = get_full_path(
+		    "Gblocks"
+#ifdef WIN32
+		    ".exe"
+#endif
+		    );
+  if (!q) {
+    fl_alert("Program Gblocks not found."
+#if !(defined(WIN32) || defined(__APPLE__))
+    "\nTo use Gblocks, download it from http://molevol.cmima.csic.es/castresana/Gblocks.html\n"
+    "and put it in a directory of your PATH"
+#endif
+    );
+    return 1;
+  }
+  Fl_Window *w = new Fl_Window(370,100);
+  w->label("Gblocks options dialog");
+  Fl_Box *b = new Fl_Box(5, 5, w->w(), 20, "Options for a less stringent selection:");
+  b->align(FL_ALIGN_LEFT + FL_ALIGN_INSIDE);
+  b->labelfont(FL_TIMES_BOLD);
+  Fl_Check_Button *b4 = new Fl_Check_Button(10,30, 350, 20, "Allow smaller final blocks");
+  Fl_Check_Button *b5 = new Fl_Check_Button(10,50, 350, 20, "Allow gap positions within the final blocks");
+  Fl_Check_Button *b2 = new Fl_Check_Button(10,70, 350, 20, "Allow less strict flanking positions");
+  Fl_Box *box2 = new Fl_Box(5, b2->y() + 20, w->w(), 20, "Option for a more stringent selection:");
+  box2->align(FL_ALIGN_LEFT + FL_ALIGN_INSIDE);
+  box2->labelfont(FL_TIMES_BOLD);
+  Fl_Check_Button *b3 = new Fl_Check_Button(10,box2->y()+20, 350, 20, "Do not allow many contiguous nonconserved positions");
+  Fl_Button *cancel = new Fl_Button(10, b3->y()+30, 50, 20, "Cancel");
+  Fl_Return_Button *ret = new Fl_Return_Button(w->w()-60, cancel->y(), 50, 20, "OK");
+  w->size(w->w(), ret->y()+22);
+  w->end();
+  w->set_non_modal();
+  w->show();
+  while(TRUE) {
+    o = Fl::readqueue();
+    if (!o) Fl::wait();
+    else if(o == cancel) {
+      free(maregion->name);
+      free(maregion);
+      break;
+      }
+    else if(o == ret)
+      break;
+    }
+  int b5_val = b5->value(); // -b5=h
+  int b4_val = b4->value(); // -b4=5
+  int b3_val = b3->value(); // -b3=4
+  int b2_val = b2->value(); // -b2=(50% of species)
+  Fl::delete_widget(w);
+  if (o == cancel) return 1;
+    
+  p = create_tmp_filename();
+  if(p == NULL) return 1;
+  strcpy(base_fname, p);
+  sprintf(fname, "%s.fst", base_fname);
+  status = save_fasta_file(fname, view->sequence, NULL,
+		      view->seqname, view->tot_seqs, view->each_length, NULL,
+			   NULL, 0, FALSE);
+  if (status) {
+    fl_alert("Cannot write to temporary file %s", fname);
+    return 1;
+    }
+  sprintf(cmd, "\"%s\" %s -p=s -t=%c", q, fname, view->protein?'p':'d');
+  if (b5_val) strcat(cmd, " -b5=h");
+  if (b4_val) strcat(cmd, " -b4=5");
+  if (b3_val) strcat(cmd, " -b3=4");
+  if (b2_val) sprintf(cmd + strlen(cmd), " -b2=%d", view->tot_seqs/2);
+#ifndef WIN32
+  strcat(cmd, " > /dev/null");
+#endif
+  system(cmd);
+  sprintf(fname, "%s.fst-gb.txts", base_fname);
+  in = fopen(fname, "r");
+  if (in == NULL) status = 1;
+  if (!status) {
+    do {
+      p = fgets(cmd, sizeof(cmd), in); 
+      if (p == NULL) { status = 1; break; }
+      }
+    while(strncmp(cmd, "Flank positions of the", 22) != 0);
+    if (p) {
+      sscanf(cmd + 22, "%d", &segment_count);
+      p = fgets(cmd, sizeof(cmd), in);
+      if (p == NULL || segment_count < 0 || strncmp(cmd, "Flanks:", 7) != 0) status = 1;
+      }
+    }
+  if (status == 0 && segment_count == 0) {
+    fl_alert("Gblocks didn't find any block of conserved sites");
+    status = 1;
+    }
+  if (!status) {
+    p = cmd;
+    previous = NULL;
+    for (num = 0; num < segment_count; num++) {
+      q = NULL;
+      p = strchr(p, '[');
+      if (p != NULL) q = strchr(p, ']');
+      if (q == NULL) {
+	l = strlen(cmd);
+	memmove(cmd, last, l + 1 - (last - cmd));
+	l -= (last - cmd);
+	p = cmd;
+	fgets(cmd + l, sizeof(cmd) - l, in);
+	p = strchr(p, '[');
+	if (p != NULL) q = strchr(p, ']');
+	if (p == NULL || q == NULL) break;
+      }
+      p++;
+      segment = (list_segments*)calloc(sizeof(list_segments), 1);
+      sscanf(p, "%d", &segment->debut);
+      p = strchr(p, ' ');
+      sscanf(p, "%d", &segment->fin);
+      p = strchr(p, ']');
+      last = p;
+      if (previous) previous->next = segment;
+      else maregion->list = segment;
+      previous = segment;
+      for(int j = segment->debut; j <= segment->fin; j++) view->region_line[j-1] = 'X';
+      }
+    if (num < segment_count) status = 1;
+    maregion->hide_when_viewasprots = FALSE;
+    }
+  if (status) {
+    free(maregion->name);
+    free(maregion);
+    }
+  if (in) fclose(in);
+#ifdef WIN32
+  sprintf(fname, "DEL %s.*", base_fname);
+#else
+  sprintf(fname, "PATH=/bin:/usr/bin rm %s.*", base_fname);
+#endif
+  system(fname);
+  return status;
+}
+
 
 int create_codon_position_mask(SEA_VIEW *view, position_mask mask, const char *regname)
+/* return values:
+ 0  no region was created
+ 1  OK
+ 2  name is already used
+ */
 {
   list_regions *old, *new_list;
   region *maregion;
@@ -200,10 +356,21 @@ int create_codon_position_mask(SEA_VIEW *view, position_mask mask, const char *r
   int i;
   /* le nom existe-t-il deja? */
   old = view->regions;
-  while(old != NULL) {
-	if(strcmp(regname, old->element->name) == 0) return FALSE;
-	old = old->next;
+  while (old != NULL) {
+    if(strcmp(regname, old->element->name) == 0) break;
+    old = old->next;
   }
+  if (old != NULL) {
+    if (mask != gblocks_sites) return 2;
+    int taille, valeur;
+    get_menu_taille_valeur(view->menu_regions, &taille, &valeur);
+    valeur = taille;
+    while(old->next) {
+      old = old->next;
+      valeur--;
+      }
+    delete_region(view, valeur);
+    }
   maregion = (region *)calloc(1,sizeof(region));
   if(maregion ==  NULL) out_of_memory();
   maregion->name = (char *)malloc(strlen(regname) + 1);
@@ -212,7 +379,10 @@ int create_codon_position_mask(SEA_VIEW *view, position_mask mask, const char *r
   if(!view->protein) maregion->hide_when_viewasprots = TRUE;
   
   memset(view->region_line, '-', view->seq_length);
-  if(mask < variable_sites) {
+  if (mask == gblocks_sites) {
+    if (create_gblocks_mask(view, maregion) ) return 0;
+  }
+  else if (mask >= position_1 && mask <= position_12) {
     previous = NULL;
     for(i = 1; i <= view->seq_length; i += 3) {
       segment = (list_segments *)calloc(1, sizeof(list_segments));
@@ -223,16 +393,16 @@ int create_codon_position_mask(SEA_VIEW *view, position_mask mask, const char *r
 	view->region_line[i] = 'X';
       }
       else {
-	segment->debut = i + mask;
+	segment->debut = i + mask - position_1;
 	segment->fin = segment->debut;
-	view->region_line[i - 1 + mask] = 'X';
+	view->region_line[i - 1 + mask - position_1] = 'X';
       }
       if(previous != NULL) previous->next = segment;
       else maregion->list = segment;
       previous = segment;
       }
     }
-  else create_variable_mask(view, maregion);
+  else if (mask == variable_sites) create_variable_mask(view, maregion);
   view->region_length = view->seq_length;
   view->region_line[view->region_length] = 0;
 
@@ -252,7 +422,7 @@ int create_codon_position_mask(SEA_VIEW *view, position_mask mask, const char *r
   Fl_Menu_Item *items = (Fl_Menu_Item *) ((Fl_Menu_ *)view->menu_file)->menu();
   items[SAVE_REGIONS].activate();
   compute_size_params(view, TRUE);
-  return TRUE;  
+  return 1;  
 }
 
 
@@ -340,7 +510,11 @@ void delete_region(SEA_VIEW *view, int rang)
 list_regions *list, *previous;
 region *maregion;
 list_segments *segment, *next;
+int taille, valeur;
 
+  get_menu_taille_valeur(view->menu_regions, &taille, &valeur);
+  ((Fl_Menu_ *)view->menu_regions)->remove(rang + 4 - 1);
+  update_menu_taille_valeur(view->menu_regions, taille - 1, 0, 4);
 list = view->regions;
 if(rang == 1) 
 	view->regions = list->next;
@@ -486,12 +660,12 @@ const char *site_mask_creation_dialog(SEA_VIEW *view, position_mask *outmask)
   const char *retval;
   static char custom_name[50];
   *outmask = custom_mask;
-  Fl_Window *w = new Fl_Window(300,200);
+  Fl_Window *w = new Fl_Window(300,220);
   w->label("Site set creation dialog");
   Fl_Input *input = new Fl_Input(180, 20, 100, 20, "Name of custom site set?");
   input->value("all sites");
-  Fl_Group  *g = new Fl_Group(0,25,w->w(),120);
-  Fl_Round_Button *mask[5];
+  Fl_Group  *g = new Fl_Group(0,40,w->w(),130);
+  Fl_Round_Button *mask[6];
   mask[0] = new Fl_Round_Button(30, input->y() + 30, 150, 20, position_mask_names[0]);
   mask[0]->type(FL_RADIO_BUTTON);
   mask[1] = new Fl_Round_Button(mask[0]->x(), mask[0]->y() + 20, 150, 20, position_mask_names[1]);
@@ -502,25 +676,30 @@ const char *site_mask_creation_dialog(SEA_VIEW *view, position_mask *outmask)
   mask[3]->type(FL_RADIO_BUTTON);
   mask[4] = new Fl_Round_Button(mask[0]->x(), mask[3]->y() + 20, 120, 20, position_mask_names[4]);
   mask[4]->type(FL_RADIO_BUTTON);
+  mask[5] = new Fl_Round_Button(mask[0]->x(), mask[4]->y() + 20, 120, 20, position_mask_names[5]);
+  mask[5]->type(FL_RADIO_BUTTON);
   g->end();
   if(view->protein) {
-    for(int i = 0; i < 4; i++) mask[i]->deactivate();
+    for(int i = 1; i <= 4; i++) mask[i]->deactivate();
     }
-  Fl_Return_Button *ok = new Fl_Return_Button(170, mask[4]->y() + mask[4]->h() + 10, 50, 30, "Ok");
+  Fl_Return_Button *ok = new Fl_Return_Button(170, mask[5]->y() + mask[5]->h() + 10, 50, 30, "Ok");
   Fl_Button *cancel = new Fl_Button(ok->x() + ok->w() + 5, ok->y(), 60, 30, "Cancel");
   w->end();
+  w->set_non_modal();
   w->show();
   while(TRUE) {
 	Fl_Widget *o = Fl::readqueue();
 	if (!o) Fl::wait();
-	else if(o == mask[0] || o == mask[1] || o == mask[2] || o == mask[3] || o == mask[4]) {
+	else if(o == mask[0] || o == mask[1] || o == mask[2] || o == mask[3] || o == mask[4] || o == mask[5]) {
 	  ((Fl_Round_Button*)o)->setonly();
+	  ok->take_focus();
 	  input->deactivate();
-	  if(o == mask[0]) {*outmask = position_1;}
-	  else if(o == mask[1]) {*outmask = position_2;}
-	  else if(o == mask[2]) {*outmask = position_3;}
-	  else if(o == mask[3]) {*outmask = position_12;}
-	  else {*outmask = variable_sites;}
+	  if(o == mask[0]) {*outmask = gblocks_sites;}
+	  else if(o == mask[1]) {*outmask = position_1;}
+	  else if(o == mask[2]) {*outmask = position_2;}
+	  else if(o == mask[3]) {*outmask = position_3;}
+	  else if(o == mask[4]) {*outmask = position_12;}
+	  else if(o == mask[5]) {*outmask = variable_sites;}
 	  retval = position_mask_names[*outmask];
 	}
 	else if(o == cancel) {
@@ -555,7 +734,11 @@ void regions_menu_callback(Fl_Widget *ob, void *extra)
 	reg_name = site_mask_creation_dialog(view, &mask);
 	if(reg_name == NULL) return;
 	if(mask == custom_mask) ok = create_full_region(view, reg_name);
-	else ok = create_codon_position_mask(view, mask, reg_name);
+	else {
+	  int retval = create_codon_position_mask(view, mask, reg_name);
+	  if (retval == 0) return;
+	  if (retval == 2) ok = 0; else ok = 1;
+	  }
 	if(!ok) {
 	  fl_alert("This name is already used: %s", reg_name);
 	  return;
@@ -565,6 +748,7 @@ void regions_menu_callback(Fl_Widget *ob, void *extra)
 	items[1].activate();
 	items[2].activate();
 	items[3].activate();
+	get_menu_taille_valeur(ob, &taille, &valeur);
 	((Fl_Menu_ *)ob)->add(reg_name, 0, NULL, NULL, FL_MENU_RADIO);
 	taille++;
 	update_menu_taille_valeur(ob, taille, taille, 4);
@@ -604,8 +788,6 @@ void regions_menu_callback(Fl_Widget *ob, void *extra)
 		  items[1].deactivate();
 		  items[2].deactivate();
 		  items[3].deactivate();
-		  ((Fl_Menu_ *)ob)->remove(valeur + 4 - 1);
-		  init_menu_taille_valeur(ob, taille - 1, 0, 4);
 		  }	
 	  }
   else	{ /* choix d'une region courante */
