@@ -33,13 +33,15 @@
 #endif
 
 #define fgets(a,b,c) my_fgets(a,b,c)
-extern "C" { char *my_fgets(char *s, int n, FILE *f); }
+extern char *my_fgets(char *s, int n, FILE *f);
 
-// myFL_CTRL is the modifier for menu shortcuts (Meta on Apple and Ctrl otherwise)
+// FL_COMMAND is the modifier for menu shortcuts (Meta on Apple and Ctrl otherwise)
+#ifndef FL_COMMAND
 #if defined(__APPLE__) 
-#define myFL_CTRL FL_META
+#define FL_COMMAND FL_META
 #else
-#define myFL_CTRL FL_CTRL
+#define FL_COMMAND FL_CTRL
+#endif
 #endif
 
 #ifdef WIN32
@@ -48,9 +50,7 @@ extern "C" { char *my_fgets(char *s, int n, FILE *f); }
 typedef const wchar_t *LPCWSTR;
 extern char *wchartoutf8(LPCWSTR in);
 extern LPCWSTR utf8towchar(const char *in);
-extern "C" { 
-	void my_bell(void); 
-}
+extern void my_bell(void); 
 #define fopen(a,b) _wfopen(utf8towchar(a), L##b)
 extern int win32_PDF_begin_document(PDF *p, const char *filename, int len, const char *optlist);
 extern void win32_PDF_end_document(PDF *p, const char *optlist);
