@@ -191,7 +191,7 @@ void refresh(char** seq, int nbseq, int option, int prot)
     for(i=0;i<lgseq;i++){
       drapeau=0;
       for(j=0;j<nbseq;j++){
-	if (!prot && (*(seq[j]+i)=='A' || *(seq[j]+i)=='C' || *(seq[j]+i)=='T' || *(seq[j]+i)=='G') || (TRANSVONLY && (*(seq[j]+i)=='R' || *(seq[j]+i)=='Y'))) { 
+	if (!prot && ((*(seq[j]+i)=='A' || *(seq[j]+i)=='C' || *(seq[j]+i)=='T' || *(seq[j]+i)=='G') || (TRANSVONLY && (*(seq[j]+i)=='R' || *(seq[j]+i)=='Y')))) { 
 	  drapeau=1;
 	  break;
 	}
