@@ -1,14 +1,73 @@
 #ifndef TREEDRAW_H
 #define TREEDRAW_H
-#include <seaview.h>
+#include "seaview.h"
 #include "FL/Fl_Round_Button.H"
 #include "FL/Fl_Button.H"
 #include "FL/Fl_Check_Button.H"
 #include <FL/Fl_Scrollbar.H>
 #include <FL/Fl_Counter.H>
-
+#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 103
+#define HAS_PRINTER
+#endif
+#if defined(HAS_PRINTER)
+#include <FL/Fl_Printer.H>
+#endif
 #define myrint(x) (int)floor(x + 0.5)
 
+#if defined(__APPLE__)
+#include <ApplicationServices/ApplicationServices.h>
+#if  (!__LP64__) && MAC_OS_X_VERSION_MAX_ALLOWED < 1070
+#define USE_PICT
+#endif
+#endif
+
+#if defined(HAS_PRINTER)
+#if (defined(__APPLE__) || defined(WIN32))
+
+class Fl_Copy_Surface : public Fl_Surface_Device {
+#ifdef __APPLE__
+  bool use_pict;
+  void *data;
+#ifdef USE_PICT
+  PicHandle mypicture;
+#endif
+#else
+  HDC oldflgc;
+#endif
+public:
+#ifdef __APPLE__
+  Fl_Copy_Surface(bool use_pict, int w, int h);
+#else
+  Fl_Copy_Surface(int w, int h);
+#endif
+  ~Fl_Copy_Surface();
+};
+#endif
+
+#ifndef NO_PDF
+#include <pdflib.h>
+class Fl_PDF_File_Device : public Fl_Paged_Device
+{
+  int width, height;
+  Fl_Surface_Device *previous_surface;
+  int left_margin, top_margin;
+public:
+  char *filename;
+  Fl_PDF_File_Device();
+  int start_job(const char *name, enum Fl_Paged_Device::Page_Format format=Fl_Paged_Device::A4, 
+		enum Fl_Paged_Device::Page_Layout layout=Fl_Paged_Device::PORTRAIT);
+  int printable_rect(int *w, int *h);
+  int 	start_page (void);
+  int 	end_page (void);
+  void 	end_job (void);
+  PDF *pdf();
+  void error_catch();
+  ~Fl_PDF_File_Device();
+};
+#endif
+#endif // HAS_PRINTER
+
+
 #if !(defined(__APPLE__) || defined(WIN32)) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  + FL_PATCH_VERSION == 130
 // for X11 under 1.3.0 only
 #include <FL/Fl_Printer.H>
@@ -20,6 +79,17 @@ public:
   int start_page();
 };
 #define Fl_Printer corr_Fl_Printer
+
+class corr_Fl_PostScript_File_Device : public Fl_PostScript_File_Device {
+  int count, m, M;
+public:
+  corr_Fl_PostScript_File_Device();
+  int start_job (int pagecount, enum Fl_Paged_Device::Page_Format format=Fl_Paged_Device::A4, 
+		   enum Fl_Paged_Device::Page_Layout layout=Fl_Paged_Device::PORTRAIT);
+  int start_page();
+};
+#define Fl_PostScript_File_Device corr_Fl_PostScript_File_Device
+
 #endif
 
 struct noeud {
