@@ -2,8 +2,9 @@
 #include <time.h>
 #include "unrooted.h"
 #include "treedraw.h"
-#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 103
+#ifdef HAS_PRINTER
 #include <FL/Fl_Printer.H>
+#include <FL/Fl_PostScript.H>
 #endif
 
 
@@ -13,11 +14,8 @@ void unrooted_scroller_cb(Fl_Widget *wgt, void *data);
 void unrooted_zoom_cb(Fl_Widget *o, void *data);
 void frame_and_draw_unrooted(FD_unrooted *fd_unrooted);
 void draw_tree(FD_unrooted *ob);
-void pdf_unrooted(FD_unrooted *fd_unrooted, const char *name);
 int debut_arbre(const char *tree, FD_unrooted *fd_unrooted);
-void my_draw_line(int dx, int dy, int fx, int fy, PDF *pdf);
-void my_draw_text(int align, int x, int y, int size, int font, 
-        char *chaine, PDF *pdf);
+void my_draw_text(int align, int x, int y, int size, int font, char *chaine);
 hit draw_line(unrooted_branch *br, FD_unrooted *ob, int doit, int char_width,
         int char_height, int descend, int ascent);
 hit try_angle_draw(float w, int *px, int *py, float *pdegrees /* clockwise degrees */, 
@@ -25,15 +23,6 @@ hit try_angle_draw(float w, int *px, int *py, float *pdegrees /* clockwise degre
 hit draw_name_angle(cp_point *phys_pos, const char *nom, FD_unrooted *ob, double angle,
         int doit, int char_width, int char_height, int descend, int color,
         int ascent);
-#ifdef NO_PDF
-hit ps_draw_name_angle(cp_point *phys_pos, const char *nom, FD_unrooted *fd_unrooted, double radians,
-					   int doit, int char_width, int char_height, int descend, int color,
-					   int ascent);
-#else
-hit pdf_draw_name_angle(cp_point *phys_pos, const char *nom, FD_unrooted *ob, double radians,
-						int doit, int char_width, int char_height, int descend, int color,
-						int ascent);
-#endif
 void draw_scale(FD_unrooted *data, int char_height, int ascent);
 int my_get_char_height(int *ascend, int *descend);
 void free_unrooted(FD_unrooted *data);
@@ -65,8 +54,8 @@ double length_log_phys(FD_unrooted *data, double p);
 double length_phys_log(FD_unrooted *data, double p);
 void squared2circular(FD_nj_plot *fd_nj_plot, Fl_Choice *o);
 void circular2squared(FD_nj_plot *fd_nj_plot);
-#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 103
-void print_unrooted(FD_unrooted *fd_unrooted);
+#ifdef HAS_PRINTER
+void print_unrooted(FD_unrooted *fd_unrooted, bool to_ps_file);
 #endif
 
 
@@ -76,7 +65,6 @@ extern void majuscules(char *p);
 extern void *check_alloc(int nbrelt, int sizelt);
 extern void my_watch_cursor(Fl_Window *win);
 extern void fl_reset_cursor(Fl_Window *win);
-extern char *prepare_ps_or_pdf_font(int font_num);
 extern char *ecrit_arbre_parenth_unrooted(FD_nj_plot *fd_nj_plot, struct noeud *root);
 extern double place_midpoint_root(struct noeud *from, struct noeud *racine);
 extern const char *make_binary_or_unrooted(char *arbre);
@@ -437,240 +425,62 @@ void draw_tree(FD_unrooted *ob)
 }
 
 
+#ifdef HAS_PRINTER
+void print_unrooted(FD_unrooted *fd_unrooted, const char *name, bool to_ps_file)
+{
+  Fl_Printer* myprinter;
+  int old_x, old_y;
+  old_x = fd_unrooted->x_offset;
+  old_y = fd_unrooted->y_offset;
+  if (to_ps_file) {
 #ifdef NO_PDF
-static int ps_paper_h; //drawable height under PostScript used to reverse vertical coordinates
-void postscript_unrooted(FD_unrooted *fd_unrooted, const char *name)
-{
-	FILE *plotfile;
-	int erreur = FALSE;
-	time_t heure;
-	const int a4_h = 842, letter_h = 792;
-	const int a4_w = 595, letter_w = 612;
-	const int margin = 25;
-
-	if(fd_unrooted->notu == 0) return;
-	Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
-	chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
-	chooser->title("Set PostScript filename");                        
-  chooser->filter("PostScript Files\t*.ps");
-	char tmp[100];
-	strcpy(tmp, extract_filename(name));
-	char *p = strrchr(tmp, '.'); if(p != NULL) *p = 0;
-	strcat(tmp, ".ps");
-	chooser->preset_file(tmp);
-	char *fname = run_and_close_native_file_chooser(chooser);
-	if(fname == NULL) return;
-	if( (plotfile = fopen(fname, "r")) != NULL) {
-		fclose(plotfile);
-		if(fl_choice("File %s already exists.", "Cancel", "Overwrite", NULL, fname) == 0) return;
-	}
-	plotfile=fopen(fname,"w");
-	if(plotfile == NULL) {
-		fl_alert("Error opening %s for writing\n", fname);
-		return;
-	}
-	char *current_ps_font = prepare_ps_or_pdf_font(fd_unrooted->current_font);
-	const int title_h = 15;
-	ps_paper_h = (int)((printout_pageformat == A4 ? a4_h : letter_h) - 2*margin - title_h);
-	int ps_width = (int)((printout_pageformat == A4 ? a4_w : letter_w) - 2*margin);
-	fprintf(plotfile,"%%!PS-Adobe-1.0\n"
-			"%%%%DocumentFonts: Times-Roman %s\n"
-			"%%%%Creator: seaview\n"
-			"%%%%Pages: 1\n"
-			"%%%%Title: %s\n"
-			"%%%%BeginFeature: *PageSize %s\n"
-		"<</PageSize[%d %d]>>setpagedevice\n"
-			"%%%%EndFeature\n"
-			"%%%%EndComments\n",
-			current_ps_font, name, printout_pageformat == A4 ? "A4" : "Letter",
-		printout_pageformat == A4 ? a4_w : letter_w, 
-		printout_pageformat == A4 ? a4_h : letter_h);
-	fprintf(plotfile,
-			"/setpacking where {true setpacking} if\n"
-			"1 setlinecap 1 setlinejoin 1 setlinewidth 0 setgray\n");
-	fprintf(plotfile,"/titlefont /Times-Roman findfont 12 scalefont def\n");
-	fprintf(plotfile, "/setclip {%d %d moveto %d 0 rlineto 0 %d rlineto %d 0 "
-	 "rlineto closepath clip newpath} def\n", margin-1, margin-1,
-	 ps_width+2, ps_paper_h+2, -ps_width-2);
-	time(&heure);
-	fprintf(plotfile, "/title {titlefont setfont\n"
-			"%d %d moveto (%s   %s) show\n} def\n", 
-			margin, ps_paper_h + margin + 5, extract_filename(name), ctime(&heure));
-// with showscaled defined, one can draw text of width w at position x y by:
-//	(text) x y w showscaled
-// before drawing text, font is set to scale 1 by:  /%s findfont setfont
-// where %s is the postscript font name
-	fprintf(plotfile, 
-			"/showscaled {gsave 3 index stringwidth pop div currentfont exch scalefont setfont"
-			" moveto show grestore} def\n");
-	
-	fprintf(plotfile,"%%%%EndProlog\n");
-	fprintf(plotfile,"%%%%Page: 1 1\n");
-  fprintf(plotfile, "%%%%PageBoundingBox: 0 0 %d %d\n", 
-	  printout_pageformat == A4 ? a4_w : letter_w, 
-	  printout_pageformat == A4 ? a4_h : letter_h);
-	fprintf(plotfile,"title ");
-	fprintf(plotfile,"setclip\n");
-	fprintf(plotfile,"%d %d translate\n", margin, margin);
-	fprintf(plotfile,"0.7 setgray 0 0 moveto %d 0 rlineto 0 %d rlineto "
-			"%d 0 rlineto closepath stroke 0 setgray \n", 
-			ps_width, ps_paper_h, -ps_width);
-	fprintf(plotfile, "/%s findfont setfont\n", current_ps_font);
-	
-	fd_unrooted->previous_w = 0; 
-	fd_unrooted->previous_h = 0;
-	fd_unrooted->comp_phys_bounds = TRUE;
-	int old_x = fd_unrooted->x_offset;
-	int old_y = fd_unrooted->y_offset;
-	fd_unrooted->x = fd_unrooted->x_offset = 0;
-	fd_unrooted->y = fd_unrooted->y_offset = 0;
-	fd_unrooted->w = ps_width;
-	fd_unrooted->h = ps_paper_h;
-	fd_unrooted->pdf = plotfile;
-	fd_unrooted->phys_max_x = fd_unrooted->x + fd_unrooted->w;
-	fd_unrooted->phys_max_y = fd_unrooted->y + fd_unrooted->h;
-	fd_unrooted->phys_min_x = fd_unrooted->x;
-	fd_unrooted->phys_min_y = fd_unrooted->y;
-	fl_font(fd_unrooted->current_font, fd_unrooted->font_size);
-	draw_tree(fd_unrooted);
-	fd_unrooted->x_offset = old_x;
-	fd_unrooted->y_offset = old_y;
-	fd_unrooted->comp_phys_bounds = FALSE;
-	fd_unrooted->pdf = NULL;	
-
-	fprintf(plotfile,"showpage\n");
-	fprintf(plotfile, "%%%%Trailer\n");
-	if(ferror(plotfile)) erreur = TRUE;
-	if(fclose(plotfile) != 0) erreur = TRUE;
-}
-
+    myprinter = (Fl_Printer*)new Fl_PostScript_File_Device();
+    if (((Fl_PostScript_File_Device*)myprinter)->start_job (1, 
+	      printout_pageformat == A4 ? Fl_Paged_Device::A4 : Fl_Paged_Device::LETTER)) return;
 #else
-
-void pdf_unrooted(FD_unrooted *fd_unrooted, const char *name)
-{
-	FILE *f;
-	const int margin = 20;
-#ifdef WIN_MAC
-    const char *encoding	= "macroman";
-#else
-    const char *encoding	= "iso8859-1";
+    myprinter = (Fl_Printer*)new Fl_PDF_File_Device();
+    if (((Fl_PDF_File_Device*)myprinter)->start_job(name, printout_pageformat == A4 ? 
+						    Fl_Paged_Device::A4 : Fl_Paged_Device::LETTER)) return;
 #endif
-	if(fd_unrooted->notu == 0) return;
-	Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
-	chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
-  chooser->filter("PDF Files\t*.pdf");
-	chooser->title("Set PDF filename");                        
-	char tmp[100];
-	strcpy(tmp, extract_filename(name));
-	char *p = strrchr(tmp, '.'); if(p != NULL) *p = 0;
-	strcat(tmp, ".pdf");
-	chooser->preset_file(tmp);
-	char *fname = run_and_close_native_file_chooser(chooser);
-	if(fname == NULL) return;
-	if( (f = fopen(fname, "r")) != NULL) {
-		fclose(f);
-		if(fl_choice("File %s already exists.", "Cancel", "Overwrite", NULL, fname) == 0) return;
-	}
-	PDF *pdf;
-	pdf = PDF_new();
-	if(pdf == NULL) return;
-	if( PDF_begin_document(pdf, fname, 0, "compatibility=1.3") == -1) {
-		PDF_delete(pdf);
-		fl_alert("Error opening %s for writing\n", fname);
-		return;
-	}
-	char *current_ps_font = prepare_ps_or_pdf_font(fd_unrooted->current_font);
-	PDF_TRY(pdf) {
-		PDF_set_info(pdf, "Title", fname );
-		PDF_set_info(pdf, "Creator", "seaview");
-		int pdf_font = PDF_load_font(pdf, current_ps_font, 0, encoding, "");
-		PDF_set_parameter(pdf, "topdown", "true");
-		PDF_begin_page_ext(pdf, printout_pageformat == A4 ? a4_width : letter_width,
-				printout_pageformat == A4 ? a4_height : letter_height, "");
-		const int title_h = 15;
-		int paper_h = (int)((printout_pageformat == A4 ? a4_height : letter_height) - 2*margin - title_h);
-		int ps_width = (int)((printout_pageformat == A4 ? a4_width : letter_width) - 2*margin);
-		
-		PDF_setlinewidth(pdf, 1);
-		PDF_setcolor(pdf, "stroke", "gray", 0.7, 0,0,0);
-		PDF_moveto(pdf, margin, margin+title_h); 
-		PDF_lineto(pdf, ps_width + margin, margin+title_h); 
-		PDF_lineto(pdf, ps_width + margin, paper_h + margin+title_h);
-		PDF_lineto(pdf, margin, paper_h+margin+title_h); 
-		PDF_closepath_stroke(pdf);
-		PDF_setcolor(pdf, "stroke", "gray", 0, 0,0,0);
-		PDF_setfont(pdf, pdf_font, fd_unrooted->font_size);
-//		PDF_setlinewidth(pdf, 2);
-		PDF_translate(pdf, margin, margin+title_h);
-		
-		fd_unrooted->previous_w = 0; 
-		fd_unrooted->previous_h = 0;
-		fd_unrooted->comp_phys_bounds = TRUE;
-		int old_x = fd_unrooted->x_offset;
-		int old_y = fd_unrooted->y_offset;
-		fd_unrooted->x = fd_unrooted->x_offset = 0;
-		fd_unrooted->y = fd_unrooted->y_offset = 0;
-		fd_unrooted->w = ps_width;
-		fd_unrooted->h = paper_h;
-		fd_unrooted->pdf = pdf;
-        fd_unrooted->phys_max_x = fd_unrooted->x + fd_unrooted->w;
-        fd_unrooted->phys_max_y = fd_unrooted->y + fd_unrooted->h;
-        fd_unrooted->phys_min_x = fd_unrooted->x;
-        fd_unrooted->phys_min_y = fd_unrooted->y;
-		draw_tree(fd_unrooted);
-		fd_unrooted->x_offset = old_x;
-		fd_unrooted->y_offset = old_y;
-		fd_unrooted->comp_phys_bounds = FALSE;
-		fd_unrooted->pdf = NULL;
-
-		time_t heure;
-		time(&heure);
-		char bigline[200];
-		sprintf(bigline, "%s  %s", extract_filename(name), ctime(&heure));
-		int t_font = PDF_load_font(pdf, "Times-Roman", 0, encoding, "");
-		PDF_setfont(pdf, t_font, 10);
-		PDF_show_xy(pdf, bigline, 0, -5);
-		PDF_end_page_ext(pdf, "");
-		PDF_end_document(pdf, "");
-		PDF_delete(pdf);
-	} /* end of PDF_TRY */
-	PDF_CATCH(pdf) {
-		fl_alert("Error while writing pdf file: [%d] %s: %s",
-				 PDF_get_errnum(pdf), PDF_get_apiname(pdf), PDF_get_errmsg(pdf));
-        PDF_delete(pdf);
-	}
-}
+    }
+  else {
+    int from, to;
+    myprinter = new Fl_Printer();
+    if (myprinter->start_job(1, &from, &to) ) return;
+  }
+#ifndef NO_PDF
+  PDF *pdf;
+  if (to_ps_file) pdf = ((Fl_PDF_File_Device*)myprinter)->pdf();
+  if ( (!to_ps_file) || setjmp(pdf_jbuf(pdf)->jbuf) == 0) { // replaces PDF_TRY
+#endif    
+    myprinter->start_page();
+    fd_unrooted->previous_w = fd_unrooted->previous_h = 0;
+    myprinter->printable_rect( &fd_unrooted->w, &fd_unrooted->h);
+    fd_unrooted->x = fd_unrooted->y = 0;
+    fd_unrooted->x_offset = fd_unrooted->y_offset = 0;
+    fd_unrooted->y += 20;
+    fd_unrooted->h -= 20;
+    time_t heure;
+    time(&heure);
+    char bigline[200];
+    sprintf(bigline, "%s  %s", extract_filename(name), ctime(&heure));
+    fl_font(FL_TIMES, 12);
+    fl_color(FL_BLACK);
+    fl_draw(bigline, fd_unrooted->x, fd_unrooted->y - 5);
+    fl_color(FL_GRAY);
+    fl_rect(fd_unrooted->x, fd_unrooted->y, fd_unrooted->w, fd_unrooted->h);
+    fl_color(FL_BLACK);
+    fd_unrooted->comp_phys_bounds = TRUE;	
+    frame_and_draw_unrooted(fd_unrooted);
+    myprinter->end_page();
+    myprinter->end_job();
+#ifndef NO_PDF
+    } // end of PDF_TRY
+    if (to_ps_file && pdf_catch(pdf)) { // replaces PDF_CATCH
+      ((Fl_PDF_File_Device*)myprinter)->error_catch();
+    }
 #endif
-
-#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 103
-void print_unrooted(FD_unrooted *fd_unrooted, const char *name)
-{
-  int from, to;
-  Fl_Printer myprinter;
-  if(myprinter.start_job(1, &from, &to) ) return;
-  myprinter.start_page();
-  fd_unrooted->previous_w = fd_unrooted->previous_h = 0;
-  myprinter.printable_rect( &fd_unrooted->w, &fd_unrooted->h);
-  fd_unrooted->x = fd_unrooted->y = 0;
-  int old_x = fd_unrooted->x_offset;
-  int old_y = fd_unrooted->y_offset;
-  fd_unrooted->x_offset = fd_unrooted->y_offset = 0;
-  fd_unrooted->y += 20;
-  fd_unrooted->h -= 20;
-  time_t heure;
-  time(&heure);
-  char bigline[200];
-  sprintf(bigline, "%s  %s", extract_filename(name), ctime(&heure));
-  fl_font(FL_TIMES, 12);
-  fl_color(FL_BLACK);
-  fl_draw(bigline, fd_unrooted->x, fd_unrooted->y - 5);
-  fl_color(FL_GRAY);
-  fl_rect(fd_unrooted->x, fd_unrooted->y, fd_unrooted->w, fd_unrooted->h);
-  fl_color(FL_BLACK);
-  fd_unrooted->comp_phys_bounds = TRUE;	
-  frame_and_draw_unrooted(fd_unrooted);
-  myprinter.end_page();
-  myprinter.end_job();
+  delete myprinter;
   fd_unrooted->x_offset = old_x;
   fd_unrooted->y_offset = old_y;
 }
@@ -749,46 +559,11 @@ return 0;
 }
 
 
-void my_draw_line(int dx, int dy, int fx, int fy, PDF *pdf)
+void my_draw_text(int align, int x, int y, int size, int current_font, char *chaine)
 {
-	if(pdf) {
-#ifdef NO_PDF
-		fprintf((FILE *)pdf," %d %d moveto", dx, ps_paper_h - dy);
-		fprintf((FILE *)pdf," %d %d lineto stroke\n", fx, ps_paper_h - fy);
-#else
-		 PDF_moveto(pdf, dx, dy);
-		 PDF_lineto(pdf, fx, fy);
-		 PDF_stroke(pdf);
-#endif
-		 }
-	else fl_line(dx,dy,fx,fy);
-}
-
-
-void my_draw_text(int align, int x, int y, int size, int current_font, 
-        char *chaine, PDF *pdf)
-{
-	if(pdf) {
-		char *current_ps_font = prepare_ps_or_pdf_font(current_font);
-#ifdef NO_PDF
-		fl_font(current_font, size);
-		float w = fl_width(chaine);
-		fprintf( (FILE *)pdf, "/%s findfont setfont\n", current_ps_font);
-		if(align == FL_ALIGN_CENTER) x -= (int)w / 2;
-		fprintf((FILE *)pdf,"(%s) %d %d %f showscaled\n", chaine, x, ps_paper_h - y, w);
-#else
-		int pdf_font = PDF_load_font(pdf, current_ps_font, 0, "host", "");
-		PDF_setfont(pdf, pdf_font, size);
-		if(align == FL_ALIGN_CENTER) x -= (int)(PDF_stringwidth(pdf, chaine, 
-						(int)PDF_get_value(pdf, "font", 0), PDF_get_value(pdf, "fontsize", 0))/2);
-		PDF_show_xy(pdf, chaine, x, y); 
-#endif
-		}
-	else {
-		fl_font(current_font, size);
-		if(align == FL_ALIGN_CENTER) x -= (int)(fl_width(chaine)/2);
-		fl_draw(chaine, x, y);
-		}
+  fl_font(current_font, size);
+  if(align == FL_ALIGN_CENTER) x -= (int)(fl_width(chaine)/2);
+  fl_draw(chaine, x, y);
 }
 
 
@@ -811,8 +586,7 @@ if(doit) {
 	phys_fin.y += fd_unrooted->y_offset;
 	phys_debut.x += fd_unrooted->x_offset;
 	phys_debut.y += fd_unrooted->y_offset;
-	my_draw_line((int)(phys_debut.x), (int)(phys_debut.y ), (int)(phys_fin.x ), (int)(phys_fin.y ), 
-				 fd_unrooted->pdf);
+	fl_line((int)(phys_debut.x), (int)(phys_debut.y ), (int)(phys_fin.x ), (int)(phys_fin.y ));
 	}
 if(br->nom != NULL) {
 /* calcul de l'angle tel que vu sur le dessin: il faut utiliser -h
@@ -824,19 +598,8 @@ if(br->nom != NULL) {
         if(angle < 0) angle += 2*M_PI;
 		if(angle > M_PI_2 && angle < 3 * M_PI_2) sprintf(txt,"%s ", br->nom);
 		else sprintf(txt, " %s", br->nom);
-		if(fd_unrooted->pdf) {
-#ifdef NO_PDF
-			result = ps_draw_name_angle(&phys_fin, txt, fd_unrooted, angle, doit, 
-										 char_width, char_height, descend, br->color, ascent);
-#else
-			result = pdf_draw_name_angle(&phys_fin, txt, fd_unrooted, angle, doit, 
-					char_width, char_height, descend, br->color, ascent);
-#endif
-		}
-		else {
-			result = draw_name_angle(&phys_fin, txt, fd_unrooted, angle, doit, 
+		result = draw_name_angle(&phys_fin, txt, fd_unrooted, angle, doit, 
 								 char_width, char_height, descend, br->color, ascent);
-			}
         if( result != NO_HIT ) return result;
         }
 return NO_HIT;
@@ -887,50 +650,6 @@ hit try_angle_draw(float w, int *px, int *py, float *pdegrees /* clockwise degre
 	return NO_HIT;
 }
 
-#ifdef NO_PDF
-hit ps_draw_name_angle(cp_point *phys_pos, const char *nom, FD_unrooted *fd_unrooted, double radians,
-						int doit, int char_width, int char_height, int descend, int color,
-						int ascent)
-{
-	int x, y;
-	float degrees = - radians * 180/M_PI;
-	x = (int)phys_pos->x;
-	y = (int)phys_pos->y;
-	float w = fl_width(nom);
-	hit result = try_angle_draw(w, &x, &y, &degrees, fd_unrooted->x,  fd_unrooted->y,  fd_unrooted->w,  fd_unrooted->h);
-	if(result != NO_HIT) return result;
-	if( ! doit) return NO_HIT;
-	
-	fprintf((FILE*)fd_unrooted->pdf, "gsave");
-	fprintf((FILE*)fd_unrooted->pdf, " %d %d translate", x, ps_paper_h - y);
-	fprintf((FILE*)fd_unrooted->pdf, " %f rotate", - degrees);
-	fprintf((FILE*)fd_unrooted->pdf, " (%s) 0 0 %f showscaled grestore\n", nom, w);
-	return NO_HIT;
-}
-#else
-hit pdf_draw_name_angle(cp_point *phys_pos, const char *nom, FD_unrooted *fd_unrooted, double radians,
-					int doit, int char_width, int char_height, int descend, int color,
-					int ascent)
-{
-	int x, y;
-	float degrees = - radians * 180/M_PI;
-	x = (int)phys_pos->x;
-	y = (int)phys_pos->y;
-	float w = PDF_stringwidth(fd_unrooted->pdf, nom, (int)PDF_get_value(fd_unrooted->pdf, "font", 0), 
-							  PDF_get_value(fd_unrooted->pdf, "fontsize", 0));
-	hit result = try_angle_draw(w, &x, &y, &degrees, fd_unrooted->x,  fd_unrooted->y,  fd_unrooted->w,  fd_unrooted->h);
-	if(result != NO_HIT) return result;
-	if( ! doit) return NO_HIT;
-	
-	PDF_save(fd_unrooted->pdf); 
-	PDF_translate(fd_unrooted->pdf, x, y); /* move origin to end of text */ 
-	PDF_rotate(fd_unrooted->pdf, -degrees); /* rotate coordinates */ 
-	PDF_show(fd_unrooted->pdf, nom); 
-	PDF_restore(fd_unrooted->pdf); 
-	return NO_HIT;
-}
-#endif
-
 
 #if defined(MICRO) || USE_XFT
 
@@ -1045,7 +764,7 @@ if(!doit) {
 	}
 chaine[0] = lettre;
 if(doit && lettre != ' ') my_draw_text(FL_ALIGN_LEFT, position->x, position->y,
-                ob->font_size, ob->current_font, chaine, ob->pdf);
+                ob->font_size, ob->current_font, chaine);
 return NO_HIT;
 }
 #endif
@@ -1062,17 +781,12 @@ phys_w = myrint(length_log_phys(fd_unrooted, log_val));
 y = (int)(1.5 * charheight) + fd_unrooted->y_offset;
 xf = (int)(fd_unrooted->w * 0.97) + fd_unrooted->x_offset;
 xd = xf - phys_w;
-if(fd_unrooted->pdf) {
-#ifndef NO_PDF
-//	PDF_setlinewidth(fd_unrooted->pdf, 1);
-#endif
-	} 
-else fl_line_style(FL_SOLID, 0, 0);
-my_draw_line(xd , y, xf, y, fd_unrooted->pdf);
+fl_line_style(FL_SOLID, 0, 0);
+fl_line(xd , y, xf, y);
 sprintf(ech_name, "%.1g", log_val);
-my_draw_text(FL_ALIGN_CENTER, (xd + xf)/2, y - charheight/3, 12, FL_TIMES, ech_name, fd_unrooted->pdf);
-my_draw_line(xd, y - charheight/3, xd, y + charheight/3 , fd_unrooted->pdf);
-my_draw_line(xf + fd_unrooted->x, y - charheight/3, xf, y + charheight/3, fd_unrooted->pdf);
+my_draw_text(FL_ALIGN_CENTER, (xd + xf)/2, y - charheight/3, 12, FL_TIMES, ech_name);
+fl_line(xd, y - charheight/3, xd, y + charheight/3);
+fl_line(xf + fd_unrooted->x, y - charheight/3, xf, y + charheight/3);
 }
 
 
@@ -1787,6 +1501,7 @@ struct Fl_Fontdesc {
 extern Fl_Fontdesc* fl_fonts;
 extern Fl_FontSize* fl_fontsize;
 extern const char* fl_encoding_;
+
 static XftFont* fontopen(const char* name, float angle);
 
 void draw_rotated_string(const char *txt, int x, int y, float degrees /*clockwise*/)
