@@ -70,6 +70,11 @@ const char *extract_dirname(const char *pathname);
 extern char *f_format_names[];
 extern char *f_format_exts[];
 extern int nbr_formats;
+#if defined(__APPLE__)
+extern const char *MG_GetBundleResourcesDir(void);
+#else
+extern char *get_prog_dir(void); 
+#endif
 
 
 extern int save_nexus_file(const char *fname, int ntaxa, int protein,
@@ -80,11 +85,7 @@ extern int save_nexus_file(const char *fname, int ntaxa, int protein,
 	int tot_comment_lines, char **comment_name, char **comment_line,
 	region *region_used, int *sel_seqs, int tot_sel_seqs, int *eachlength,
 	int tot_trees, char **trees, const Fl_Menu_Item *items);
-extern "C" {
-	char *my_fgets(char *s, int n, FILE *f);
-}
-
-
+extern char *my_fgets(char *s, int n, FILE *f);
 
 
 int read_mase_seqs_header(const char *masefname, char ***pseq, char ***pseqname, 
@@ -1531,14 +1532,6 @@ for(l = nl; l > 0; l--) {
 }
 
 
-extern "C" { 
-#if defined(__APPLE__)
-	const char *MG_GetBundleResourcesDir(void);
-#else
-  char *get_prog_dir(void); 
-#endif
-	}
-
 #if !(defined(WIN32) || defined(__APPLE__))
 static char seaview_prog_dir[200] = "";
 void inform_prog_dir(const char *arg0)
