@@ -273,7 +273,7 @@ Fl_Button *b = new Fl_Return_Button(obj->x(), obj->y() + obj->h() + 3, 50, 20, "
 b->callback(ask_gc_callback, obj);
 b = new Fl_Button(obj->x() + obj->w() - 55 , b->y(), 55, 20, "Cancel");
 b->callback(ignore_gc_callback, &status);
-b->shortcut(myFL_CTRL | 'w');
+b->shortcut(FL_COMMAND | 'w');
 win->end();
 win->resizable(new Fl_Box(obj->x() + 55, obj->y(), 50, obj->h() ));
 win->size_range(100, 100);
