@@ -1,5 +1,5 @@
 #ifdef WIN32
-
+#include "treedraw.h"
 #include <Windows.h>
 #include <FL/Fl.H>
 #include "FL/fl_ask.H"
@@ -16,13 +16,9 @@
 #endif
 
 /* included functions */
-void *MG_PrepareCopy(int w, int h);
-void MG_CompleteCopy(void *oldflgc);
-extern "C" {
-	void my_bell(void);
-	int mysystem(const char *command);
-	char *get_prog_dir(void);
-}
+void my_bell(void);
+int mysystem(const char *command);
+char *get_prog_dir(void);
 char **getutf8args(int *pargc);
 #if !(FL_MAJOR_VERSION >= 1 && FL_MINOR_VERSION >= 3)
 void draw_rotated_string(const char *strDraw, int x, int y, float degrees /*clockwise*/);
@@ -31,41 +27,36 @@ void draw_rotated_string(const char *strDraw, int x, int y, float degrees /*cloc
 /* extern vars & functions */
 extern char *wchartoutf8(const wchar_t *in);
 
-
-void *MG_PrepareCopy(int w, int h)
-/* returns NULL iff error
- */
+Fl_Copy_Surface::Fl_Copy_Surface(int w, int h) : Fl_Surface_Device(new Fl_GDI_Graphics_Driver())
 {
-	HDC oldflgc = fl_gc;
-	int factor = 32; // empirically set
-	RECT rect; rect.left = 0; rect.top = 0; rect.right=w*factor; rect.bottom=h*factor;
-	fl_gc = CreateEnhMetaFile (NULL, NULL, &rect, NULL);
-	if (fl_gc != NULL) {
-		SetTextAlign(fl_gc, TA_BASELINE|TA_LEFT);
-		SetBkMode(fl_gc, TRANSPARENT);
-		return oldflgc ? oldflgc : fl_gc;
-    } 
-	else {
-		fl_gc = oldflgc;
-		return NULL;
-	}
+  HDC oldflgc = fl_gc;
+  int factor = 32; // empirically set
+  RECT rect; rect.left = 0; rect.top = 0; rect.right=w*factor; rect.bottom=h*factor;
+  fl_gc = CreateEnhMetaFile (NULL, NULL, &rect, NULL);
+  if (fl_gc != NULL) {
+    SetTextAlign(fl_gc, TA_BASELINE|TA_LEFT);
+    SetBkMode(fl_gc, TRANSPARENT);
+  } 
+  else {
+    fl_gc = oldflgc;
+    }
 }
 
-
-void MG_CompleteCopy(void *oldflgc)
+Fl_Copy_Surface::~Fl_Copy_Surface()
 {
-	if(oldflgc == fl_gc) oldflgc = NULL;
-	HENHMETAFILE hmf = CloseEnhMetaFile (fl_gc);
-	if ( hmf != NULL ) {
-		if ( OpenClipboard (NULL) ){
-			EmptyClipboard ();
-			SetClipboardData (CF_ENHMETAFILE, hmf);
-			CloseClipboard ();
-		}
-		DeleteEnhMetaFile(hmf);
-	}
-	DeleteDC(fl_gc);
-	fl_gc = (HDC)oldflgc;
+  if(oldflgc == fl_gc) oldflgc = NULL;
+  HENHMETAFILE hmf = CloseEnhMetaFile (fl_gc);
+  if ( hmf != NULL ) {
+    if ( OpenClipboard (NULL) ){
+      EmptyClipboard ();
+      SetClipboardData (CF_ENHMETAFILE, hmf);
+      CloseClipboard ();
+    }
+    DeleteEnhMetaFile(hmf);
+  }
+  DeleteDC(fl_gc);
+  fl_gc = oldflgc;
+  delete driver();
 }
 
 
@@ -181,6 +172,10 @@ static size_t pdf_write_proc(PDF *p, void *data, size_t size)
   return fwrite(data, 1, size, pdf_output);
 }
 
+#ifdef PDF_begin_document
+#undef PDF_begin_document 
+#undef PDF_end_document 
+#endif
 // because PDF_begin_document fails on WIN32 if non ascii filename
 int win32_PDF_begin_document(PDF *p, const char *filename, int len, const char *optlist)
 {
