@@ -7,7 +7,7 @@
 
 #ifndef NO_PDF
 #include <pdflib.h>
-extern PDF *pdf;
+static PDF *pdf;
 #endif
 
 
@@ -212,7 +212,7 @@ postscript->callback(plot_button_proc, fdui);
 #ifndef WIN32
 fin += 2;
 Fl_Widget *close = cre_button(fin, curr_y, &width, but_height, fontsize, "Close");
-((Fl_Button *)close)->shortcut(myFL_CTRL | 'w');
+((Fl_Button *)close)->shortcut(FL_COMMAND | 'w');
 fin += width;
 close->callback(exit_button_proc, fdui);
 #endif
